@@ -6,7 +6,7 @@
 @protocol ShellProtocolDelegate <NSObject>
 - (void)onSyncAdd:(NSString *)path withSyncName:(NSString*)syncName;
 - (void)onSyncDel:(NSString *)path withSyncName:(NSString*)syncName;
-- (void)onItemChanged:(NSString *)path withState:(int)state shouldShowBadges:(int)badge;
+- (void)onItemChanged:(NSString *)path withState:(int)state shouldShowBadges:(int)badge isIncomingShare:(int) share;
 - (void)cleanAll;
 @end
 
