@@ -293,7 +293,11 @@ static void mega_ext_on_open_previous_selected(NautilusMenuItem *item, gpointer
 // Check the state of the selected files
 // to show the menu item "Upload to MEGA", "Get MEGA link" or both
 // Return: list of NautilusMenuItem
-static GList *mega_ext_get_file_items(NautilusMenuProvider *provider, G_GNUC_UNUSED GtkWidget *window, GList *files)
+static GList *mega_ext_get_file_items(NautilusMenuProvider *provider,
+                                      #if (NAUTILUS_EXT_API_VERSION < 4)
+                                      G_GNUC_UNUSED GtkWidget *window,
+                                      #endif
+                                      GList *files)
 {
     MEGAExt *mega_ext = MEGA_EXT(provider);
     GList *l, *l_out = NULL;
@@ -391,15 +395,19 @@ static GList *mega_ext_get_file_items(NautilusMenuProvider *provider, G_GNUC_UNU
         NautilusMenuItem *item;
 
         out = mega_ext_client_get_string(mega_ext, STRING_UPLOAD, unsyncedFiles, unsyncedFolders);
-        item = nautilus_menu_item_new("MEGAExtension::upload_to_mega", out, "Upload files to you MEGA account", "mega");
-        g_free(mega_ext->string_upload);
-        mega_ext->string_upload = g_strdup(out);
-        g_free(out);
 
-        g_signal_connect(item, "activate", G_CALLBACK(mega_ext_on_upload_selected), provider);
-        g_object_set_data_full((GObject*)item, "MEGAExtension::files", nautilus_file_info_list_copy(files), (GDestroyNotify)nautilus_file_info_list_free);
-        nautilus_menu_append_item(subMenu, item);
-        g_object_unref(item);
+        if(out)
+        {
+            item = nautilus_menu_item_new("MEGAExtension::upload_to_mega", out, "Upload files to you MEGA account", "mega");
+            g_free(mega_ext->string_upload);
+            mega_ext->string_upload = g_strdup(out);
+            g_free(out);
+
+            g_signal_connect(item, "activate", G_CALLBACK(mega_ext_on_upload_selected), provider);
+            g_object_set_data_full((GObject*)item, "MEGAExtension::files", nautilus_file_info_list_copy(files), (GDestroyNotify)nautilus_file_info_list_free);
+            nautilus_menu_append_item(subMenu, item);
+            g_object_unref(item);
+        }
      }
 
     // if there any synced files / folders selected
@@ -408,43 +416,53 @@ static GList *mega_ext_get_file_items(NautilusMenuProvider *provider, G_GNUC_UNU
         NautilusMenuItem *item;
 
         out = mega_ext_client_get_string(mega_ext, STRING_GETLINK, syncedFiles, syncedFolders);
-        item = nautilus_menu_item_new("MEGAExtension::get_mega_link", out, "Get MEGA link", "mega");
-        g_free(mega_ext->string_getlink);
-        mega_ext->string_getlink = g_strdup(out);
-        g_free(out);
+        if(out)
+        {
+            item = nautilus_menu_item_new("MEGAExtension::get_mega_link", out, "Get MEGA link", "mega");
+            g_free(mega_ext->string_getlink);
+            mega_ext->string_getlink = g_strdup(out);
+            g_free(out);
 
-        g_signal_connect(item, "activate", G_CALLBACK(mega_ext_on_get_link_selected), provider);
-        g_object_set_data_full((GObject*)item, "MEGAExtension::files", nautilus_file_info_list_copy(files), (GDestroyNotify)nautilus_file_info_list_free);
-        nautilus_menu_append_item(subMenu, item);
-        g_object_unref(item);
+            g_signal_connect(item, "activate", G_CALLBACK(mega_ext_on_get_link_selected), provider);
+            g_object_set_data_full((GObject*)item, "MEGAExtension::files", nautilus_file_info_list_copy(files), (GDestroyNotify)nautilus_file_info_list_free);
+            nautilus_menu_append_item(subMenu, item);
+            g_object_unref(item);
+        }
 
         if ( ((syncedFiles + syncedFolders) == 1 ) && ( (unsyncedFiles+unsyncedFolders) == 0  ) )
         {
             if (syncedFolders)
             {
                 out = mega_ext_client_get_string(mega_ext, STRING_VIEW_ON_MEGA, 0, 0);
-                item = nautilus_menu_item_new("MEGAExtension::view_on_mega", out, "View on MEGA", "mega");
-                g_free(mega_ext->string_viewonmega);
-                mega_ext->string_viewonmega = g_strdup(out);
-                g_free(out);
 
-                g_signal_connect(item, "activate", G_CALLBACK(mega_ext_on_view_on_mega_selected), provider);
-                g_object_set_data_full((GObject*)item, "MEGAExtension::files", nautilus_file_info_list_copy(files), (GDestroyNotify)nautilus_file_info_list_free);
-                nautilus_menu_append_item(subMenu, item);
-                g_object_unref(item);
+                if(out)
+                {
+                    item = nautilus_menu_item_new("MEGAExtension::view_on_mega", out, "View on MEGA", "mega");
+                    g_free(mega_ext->string_viewonmega);
+                    mega_ext->string_viewonmega = g_strdup(out);
+                    g_free(out);
+
+                    g_signal_connect(item, "activate", G_CALLBACK(mega_ext_on_view_on_mega_selected), provider);
+                    g_object_set_data_full((GObject*)item, "MEGAExtension::files", nautilus_file_info_list_copy(files), (GDestroyNotify)nautilus_file_info_list_free);
+                    nautilus_menu_append_item(subMenu, item);
+                    g_object_unref(item);
+                }
             }
             else
             {
                 out = mega_ext_client_get_string(mega_ext, STRING_VIEW_VERSIONS, 0, 0);
-                item = nautilus_menu_item_new("MEGAExtension::view_previous_versions", out, "View previous versions", "mega");
-                g_free(mega_ext->string_viewprevious);
-                mega_ext->string_viewprevious = g_strdup(out);
-                g_free(out);
+                if(out)
+                {
+                    item = nautilus_menu_item_new("MEGAExtension::view_previous_versions", out, "View previous versions", "mega");
+                    g_free(mega_ext->string_viewprevious);
+                    mega_ext->string_viewprevious = g_strdup(out);
+                    g_free(out);
 
-                g_signal_connect(item, "activate", G_CALLBACK(mega_ext_on_open_previous_selected), provider);
-                g_object_set_data_full((GObject*)item, "MEGAExtension::files", nautilus_file_info_list_copy(files), (GDestroyNotify)nautilus_file_info_list_free);
-                nautilus_menu_append_item(subMenu, item);
-                g_object_unref(item);
+                    g_signal_connect(item, "activate", G_CALLBACK(mega_ext_on_open_previous_selected), provider);
+                    g_object_set_data_full((GObject*)item, "MEGAExtension::files", nautilus_file_info_list_copy(files), (GDestroyNotify)nautilus_file_info_list_free);
+                    nautilus_menu_append_item(subMenu, item);
+                    g_object_unref(item);
+                }
             }
         }
     }
@@ -527,12 +545,24 @@ static NautilusOperationResult mega_ext_update_file_info(NautilusInfoProvider *p
     return NAUTILUS_OPERATION_COMPLETE;
 }
 
-static void mega_ext_menu_provider_iface_init(NautilusMenuProviderIface *iface, G_GNUC_UNUSED gpointer iface_data)
+static void mega_ext_menu_provider_iface_init(
+        #if (NAUTILUS_EXT_API_VERSION < 4)
+        NautilusMenuProviderIface *iface,
+        #else
+        NautilusMenuProviderInterface *iface,
+        #endif
+        G_GNUC_UNUSED gpointer iface_data)
 {
     iface->get_file_items = mega_ext_get_file_items;
 }
 
-static void mega_ext_info_provider_iface_init(NautilusInfoProviderIface *iface, G_GNUC_UNUSED gpointer iface_data)
+static void mega_ext_info_provider_iface_init(
+        #if (NAUTILUS_EXT_API_VERSION < 4)
+        NautilusInfoProviderIface *iface,
+        #else
+        NautilusInfoProviderInterface *iface,
+        #endif
+        G_GNUC_UNUSED gpointer iface_data)
 {
     iface->update_file_info = mega_ext_update_file_info;
 }
