@@ -10,40 +10,45 @@
 #include <QLocalSocket>
 #include <QDataStream>
 #include <QQueue>
-#include <QNetworkConfigurationManager>
 #include <QNetworkInterface>
+#include <QFutureWatcher>
+#include <QQmlFileSelector>
+
 #include <memory>
+#include <QQmlEngine>
 
 #include "gui/TransferManager.h"
-#include "gui/NodeSelector.h"
 #include "gui/InfoDialog.h"
 #include "gui/UpgradeOverStorage.h"
-#include "gui/SetupWizard.h"
 #include "gui/SettingsDialog.h"
-#include "gui/UploadToMegaDialog.h"
 #include "gui/DownloadFromMegaDialog.h"
 #include "gui/StreamingFromMegaDialog.h"
 #include "gui/ImportMegaLinksDialog.h"
 #include "gui/MultiQFileDialog.h"
 #include "gui/PasteMegaLinksDialog.h"
 #include "gui/ChangeLogDialog.h"
-#include "gui/InfoWizard.h"
-#include "control/Preferences.h"
+#include "control/Preferences/Preferences.h"
 #include "control/HTTPServer.h"
 #include "control/MegaUploader.h"
 #include "control/MegaDownloader.h"
 #include "control/UpdateTask.h"
 #include "control/MegaSyncLogger.h"
 #include "control/ThreadPool.h"
-#include "control/MegaController.h"
-#include "model/Model.h"
+#include "control/Utilities.h"
+#include "syncs/control/SyncInfo.h"
+#include "syncs/control/SyncController.h"
 #include "megaapi.h"
 #include "QTMegaListener.h"
-#include "QFilterAlertsModel.h"
+#include "gui/QFilterAlertsModel.h"
 #include "gui/MegaAlertDelegate.h"
 #include "gui/VerifyLockMessage.h"
-#include "DesktopNotifications.h"
+#include "notifications/DesktopNotifications.h"
+#include "ScanStageController.h"
 #include "TransferQuota.h"
+#include "BlockingStageProgressController.h"
+
+class TransfersModel;
+class StalledIssuesModel;
 
 #ifdef __APPLE__
     #include "gui/MegaSystemTrayIcon.h"
@@ -54,30 +59,11 @@
 
 Q_DECLARE_METATYPE(QQueue<QString>)
 
-class TransferMetaData
-{
-public:
-    TransferMetaData(int direction, int total = 0, int pending = 0, QString path = QString())
-                    : transferDirection(direction), totalTransfers(total), pendingTransfers(pending),
-                      localPath(path), totalFiles(0), totalFolders(0),
-                      transfersFileOK(0), transfersFolderOK(0),
-                      transfersFailed(0), transfersCancelled(0) {}
-
-    int totalTransfers;
-    int pendingTransfers;
-    int totalFiles;
-    int totalFolders;
-    int transfersFileOK;
-    int transfersFolderOK;
-    int transfersFailed;
-    int transfersCancelled;
-    int transferDirection;
-    QString localPath;
-};
-
-class Notificator;
-class MEGASyncDelegateListener;
-class ShellNotifier;
+class LogoutController;
+class TransferMetadata;
+class DuplicatedNodeDialog;
+class LoginController;
+class AccountStatusController;
 
 enum GetUserStatsReason {
     USERSTATS_LOGGEDIN,
@@ -117,13 +103,11 @@ public:
     static QString applicationDataPath();
     QString getCurrentLanguageCode();
     void changeLanguage(QString languageCode);
-    void updateTrayIcon();
-    void repositionInfoDialog();
+
+    QString getFormattedDateByCurrentLanguage(const QDateTime& datetime, QLocale::FormatType format = QLocale::FormatType::LongFormat) const;
 
     void onEvent(mega::MegaApi *api, mega::MegaEvent *event) override;
-    void onRequestStart(mega::MegaApi* api, mega::MegaRequest *request) override;
     void onRequestFinish(mega::MegaApi* api, mega::MegaRequest *request, mega::MegaError* e) override;
-    void onRequestTemporaryError(mega::MegaApi *api, mega::MegaRequest *request, mega::MegaError* e) override;
     void onTransferStart(mega::MegaApi *api, mega::MegaTransfer *transfer) override;
     void onTransferFinish(mega::MegaApi* api, mega::MegaTransfer *transfer, mega::MegaError* e) override;
     void onTransferUpdate(mega::MegaApi *api, mega::MegaTransfer *transfer) override;
@@ -134,13 +118,6 @@ public:
     void onNodesUpdate(mega::MegaApi* api, mega::MegaNodeList *nodes) override;
     void onReloadNeeded(mega::MegaApi* api) override;
     void onGlobalSyncStateChanged(mega::MegaApi *api) override;
-    void onSyncStateChanged(mega::MegaApi *api,  mega::MegaSync *sync) override;
-    void onSyncFileStateChanged(mega::MegaApi *api, mega::MegaSync *sync, std::string *localPath, int newState) override;
-
-    void onSyncAdded(mega::MegaApi *api, mega::MegaSync *sync, int additionState) override;
-    void onSyncDisabled(mega::MegaApi *api, mega::MegaSync *sync) override;
-    void onSyncEnabled(mega::MegaApi *api, mega::MegaSync *sync) override;
-    void onSyncDeleted(mega::MegaApi *api, mega::MegaSync *sync) override;
 
     virtual void onCheckDeferredPreferencesSync(bool timeout);
     void onGlobalSyncStateChangedImpl(mega::MegaApi* api, bool timeout);
@@ -148,21 +125,24 @@ public:
     void showAddSyncError(mega::MegaRequest *request, mega::MegaError* e, QString localpath, QString remotePath = QString());
     void showAddSyncError(int errorCode, QString localpath, QString remotePath = QString());
 
-
     /**
      * @brief Migrate sync configuration to sdk cache
-     * @param email of sync configuration to migrate from previous sessions
+     * @param email of sync configuration to migrate from sprevious sessions
      */
     void migrateSyncConfToSdk(QString email = QString());
 
     mega::MegaApi *getMegaApi() { return megaApi; }
+    QQmlEngine *qmlEngine() { return mEngine;}
+    mega::MegaApi *getMegaApiFolders() { return megaApiFolders; }
     std::unique_ptr<mega::MegaApiLock> megaApiLock;
 
+    QString getMEGAString(){return QLatin1String("MEGA");}
+
     void cleanLocalCaches(bool all = false);
-    void showInfoMessage(QString message, QString title = tr("MEGAsync"));
-    void showWarningMessage(QString message, QString title = tr("MEGAsync"));
-    void showErrorMessage(QString message, QString title = tr("MEGAsync"));
-    void showNotificationMessage(QString message, QString title = tr("MEGAsync"));
+    void showInfoMessage(QString message, QString title = MegaSyncApp->getMEGAString());
+    void showWarningMessage(QString message, QString title = MegaSyncApp->getMEGAString());
+    void showErrorMessage(QString message, QString title = MegaSyncApp->getMEGAString());
+    void showNotificationMessage(QString message, QString title = MegaSyncApp->getMEGAString());
     void setUploadLimit(int limit);
     void setMaxUploadSpeed(int limit);
     void setMaxDownloadSpeed(int limit);
@@ -172,7 +152,6 @@ public:
     void stopUpdateTask();
     void applyProxySettings();
     void updateUserStats(bool storage, bool transfer, bool pro, bool force, int source);
-    void addRecentFile(QString fileName, long long fileHandle, QString localPath = QString(), QString nodeKey = QString());
     void checkForUpdates();
     // Actually show InfoDialog view, not tray menu.
     void showTrayMenu(QPoint *point = NULL);
@@ -183,68 +162,73 @@ public:
     // Create menus for the "..." menu in InfoDialog view.
     void createInfoDialogMenus();
     void toggleLogging();
-    QList<mega::MegaTransfer* > getFinishedTransfers();
-    int getNumUnviewedTransfers();
-    void removeFinishedTransfer(int transferTag);
-    void removeAllFinishedTransfers();
-    void showVerifyAccountInfo();
 
-    void removeFinishedBlockedTransfer(int transferTag);
-    bool finishedTransfersWhileBlocked(int transferTag);
-
-    mega::MegaTransfer* getFinishedTransferByTag(int tag);
-    TransferMetaData* getTransferAppData(unsigned long long appDataID);
     bool notificationsAreFiltered();
     bool hasNotifications();
     bool hasNotificationsOfType(int type);
     std::shared_ptr<mega::MegaNode> getRootNode(bool forceReset = false);
-    std::shared_ptr<mega::MegaNode> getInboxNode(bool forceReset = false);
+    std::shared_ptr<mega::MegaNode> getVaultNode(bool forceReset = false);
     std::shared_ptr<mega::MegaNode> getRubbishNode(bool forceReset = false);
+    void resetRootNodes();
+    void initLocalServer();
+    void onboardingFinished(bool fastLogin);
+    void onLoginFinished();
+    void onLogout();
 
     MegaSyncLogger& getLogger() const;
     void pushToThreadPool(std::function<void()> functor);
-    SetupWizard *getSetupWizard() const;
+
+    TransfersModel* getTransfersModel(){return mTransfersModel;}
+    StalledIssuesModel* getStalledIssuesModel(){return mStalledIssuesModel;}
 
     /**
      * @brief migrates sync configuration and fetches nodes
      * @param email of sync configuration to migrate from previous sessions. If present
      * syncs configured in previous sessions will be loaded.
      */
-    void fetchNodes(QString email = QString());
-    void whyAmIBlocked(bool periodicCall = false);
-    bool showSyncOverquotaDialog();
+    QPointer<OverQuotaDialog> showSyncOverquotaDialog();
     bool finished() const;
     bool isInfoDialogVisible() const;
 
-    int getBlockState() const;
+    void requestUserData(); //groups user attributes retrieving, getting PSA, ... to be retrieved after login in
 
     void updateTrayIconMenu();
 
-    mega::MegaPricing *getPricing() const;
+    std::shared_ptr<mega::MegaPricing> getPricing() const;
+
+    QuotaState getTransferQuotaState() const;
+    std::shared_ptr<TransferQuota> getTransferQuota() const;
 
     int getAppliedStorageState() const;
     bool isAppliedStorageOverquota() const;
     void reloadSyncsInSettings();
 
     void raiseInfoDialog();
+    bool raiseGuestDialog();
+    void raiseOnboardingDialog();
+    void raiseOrHideInfoGuestDialog();
+    bool isShellNotificationProcessingOngoing();
+
+    QSystemTrayIcon* getTrayIcon();
+    LoginController* getLoginController();
 
 signals:
     void startUpdaterThread();
     void tryUpdate();
     void installUpdate();
-    void unityFixSignal();
     void clearAllFinishedTransfers();
-    void clearFinishedTransfer(int transferTag);
     void fetchNodesAfterBlock();
-    void closeSetupWizard();
-    void setupWizardCreated();
     void unblocked();
     void nodeMoved(mega::MegaHandle handle);
     void nodeAttributesChanged(mega::MegaHandle handle);
     void blocked();
     void storageStateChanged(int);
+    void pauseStateChanged();
+    void addBackup();
+    void shellNotificationsProcessed();
 
 public slots:
+    void updateTrayIcon();
     void unlink(bool keepLogs = false);
     void showInterface(QString);
     void trayIconActivated(QSystemTrayIcon::ActivationReason reason);
@@ -252,15 +236,15 @@ public slots:
     void start();
     void openSettings(int tab = -1);
     void openSettingsAddSync(mega::MegaHandle megaFolderHandle);
-    void openInfoWizard();
+    void openGuestDialog();
+    void openOnboardingDialog();
     void importLinks();
     void officialWeb();
     void goToMyCloud();
     void pauseTransfers();
     void showChangeLog();
     void uploadActionClicked();
-    void loginActionClicked();
-    void copyFileLink(mega::MegaHandle fileHandle, QString nodeKey = QString());
+    void uploadActionClickedFromWindowAfterOverQuotaCheck();
     void downloadActionClicked();
     void streamActionClicked();
     void transferManagerActionClicked(int tab = 0);
@@ -272,14 +256,14 @@ public slots:
     void shellViewOnMega(QByteArray localPath, bool versions);
     void shellViewOnMega(mega::MegaHandle handle, bool versions);
     void exportNodes(QList<mega::MegaHandle> exportList, QStringList extraLinks = QStringList());
-    void externalDownload(QQueue<mega::MegaNode *> newDownloadQueue);
-    void externalDownload(QString megaLink, QString auth);
+    void externalDownload(QQueue<WrappedNode *> newDownloadQueue);
+    void externalLinkDownload(QString megaLink, QString auth);
     void externalFileUpload(qlonglong targetFolder);
     void externalFolderUpload(qlonglong targetFolder);
     void externalFolderSync(qlonglong targetFolder);
+    void externalAddBackup();
     void externalOpenTransferManager(int tab);
     void internalDownload(long long handle);
-    void onLinkImportFinished();
     void onRequestLinksFinished();
     void onUpdateCompleted();
     void onUpdateAvailable(bool requested);
@@ -287,31 +271,26 @@ public slots:
     void onUpdateNotFound(bool requested);
     void onUpdateError();
     void rebootApplication(bool update = true);
-    void exitApplication(bool force = false);
+    void tryExitApplication(bool force = false);
     void highLightMenuEntry(QAction* action);
     void pauseTransfers(bool pause);
     void checkNetworkInterfaces();
     void checkMemoryUsage();
     void checkOverStorageStates();
+    void checkOverQuotaStates();
     void periodicTasks();
     void cleanAll();
-    void onDupplicateLink(QString link, QString name, mega::MegaHandle handle);
     void onInstallUpdateClicked();
+    void onAboutClicked();
     void showInfoDialog();
     void showInfoDialogNotifications();
     void triggerInstallUpdate();
     void scanningAnimationStep();
-    void setupWizardFinished(int result);
-    void storageOverquotaDialogFinished(int result);
-    void infoWizardDialogFinished(int result);
-    void runConnectivityCheck();
-    void onConnectivityCheckSuccess();
-    void onConnectivityCheckError();
+    void clearDownloadAndPendingLinks();
     void proExpirityTimedOut();
-    void userAction(int action);
-    void showSetupWizard(int action);
     void applyNotificationFilter(int opt);
     void changeState();
+
 #ifdef _WIN32
     void changeDisplay(QScreen *disp);
 #endif
@@ -319,56 +298,52 @@ public slots:
     void handleMEGAurl(const QUrl &url);
     void handleLocalPath(const QUrl &url);
     void clearUserAttributes();
-    void clearViewedTransfers();
-    void onCompletedTransfersTabActive(bool active);
-    void checkFirstTransfer();
     void checkOperatingSystem();
-    void notifyItemChange(QString path, int newState);
+    void notifyChangeToAllFolders();
     int getPrevVersion();
     void onDismissStorageOverquota(bool overStorage);
     void showNotificationFinishedTransfers(unsigned long long appDataId);
-    void renewLocalSSLcert();
-    void onHttpServerConnectionError();
+    void transferBatchFinished(unsigned long long appDataId, bool fromCancellation);
     void onGlobalSyncStateChangedTimeout();
     void onCheckDeferredPreferencesSyncTimeout();
     void updateStatesAfterTransferOverQuotaTimeHasExpired();
 #ifdef __APPLE__
     void enableFinderExt();
 #endif
+
 private slots:
     void openFolderPath(QString path);
     void registerUserActivity();
     void PSAseen(int id);
-    void onSyncStateChanged(std::shared_ptr<SyncSetting> syncSettings);
-    void onSyncDeleted(std::shared_ptr<SyncSetting> syncSettings);
-    void onSyncDisabled(std::shared_ptr<SyncSetting> syncSetting);
-    void onSyncEnabled(std::shared_ptr<SyncSetting> syncSetting);
+    void onSyncModelUpdated(std::shared_ptr<SyncSettings> syncSettings);
     void onBlocked();
     void onUnblocked();
+    void onTransfersModelUpdate();
+
+    void startingUpload();
+    void cancelScanningStage();
+
+protected slots:
+    void onUploadsCheckedAndReady(QPointer<DuplicatedNodeDialog> checkDialog);
+    void onPasteMegaLinksDialogFinish(QPointer<PasteMegaLinksDialog>);
+    void onDownloadFromMegaFinished(QPointer<DownloadFromMegaDialog> dialog);
 
 protected:
     void createTrayIcon();
     void createGuestMenu();
     bool showTrayIconAlwaysNEW();
-    void loggedIn(bool fromWizard);
-    void startSyncs(QList<PreConfiguredSync> syncs); //initializes syncs configured in the setup wizard
     void applyStorageState(int state, bool doNotAskForUserStats = false);
     void processUploadQueue(mega::MegaHandle nodeHandle);
     void processDownloadQueue(QString path);
-    void unityFix();
     void disableSyncs();
     void restoreSyncs();
-    void closeDialogs(bool bwoverquota = false);
-    void calculateInfoDialogCoordinates(QDialog *dialog, int *posx, int *posy);
+    void createTransferManagerDialog(TransfersWidget::TM_TAB tab);
     void deleteMenu(QMenu *menu);
     void startHttpServer();
     void startHttpsServer();
-    void initLocalServer();
     void refreshStorageUIs();
     void manageBusinessStatus(int64_t event);
-    void requestUserData(); //groups user attributes retrieving, getting PSA, ... to be retrieved after login in
     void populateUserAlerts(mega::MegaUserAlertList *list, bool copyRequired);
-    std::vector<std::unique_ptr<mega::MegaEvent>> eventsPendingLoggedIn;
 
     bool eventFilter(QObject *obj, QEvent *e) override;
     void createInfoDialog();
@@ -377,12 +352,13 @@ protected:
 
     QAction *guestSettingsAction;
     QAction *initialExitAction;
-    std::unique_ptr<QMenu> initialTrayMenu;
+    QPointer<QMenu> initialTrayMenu;
 
 #ifdef _WIN32
-    std::unique_ptr<QMenu> windowsMenu;
+    QPointer<QMenu> windowsMenu;
     QAction *windowsExitAction;
     QAction *windowsUpdateAction;
+    QAction *windowsAboutAction;
     QAction *windowsImportLinksAction;
     QAction *windowsUploadAction;
     QAction *windowsDownloadAction;
@@ -391,12 +367,9 @@ protected:
     QAction *windowsSettingsAction;
 #endif
 
-    std::unique_ptr<VerifyLockMessage> verifyEmail;
-    std::unique_ptr<QMenu> infoDialogMenu;
-    std::unique_ptr<QMenu> guestMenu;
+    QPointer<QMenu> infoDialogMenu;
+    QPointer<QMenu> guestMenu;
     QMenu emptyMenu;
-    std::unique_ptr<QMenu> syncsMenu;
-    QSignalMapper *menuSignalMapper;
 
     MenuItemAction *exitAction;
     MenuItemAction *settingsAction;
@@ -405,10 +378,11 @@ protected:
     MenuItemAction *downloadAction;
     MenuItemAction *streamAction;
     MenuItemAction *myCloudAction;
-    MenuItemAction *addSyncAction;
-
     MenuItemAction *updateAction;
+    MenuItemAction *aboutAction;
     QAction *showStatusAction;
+    QPointer<SyncsMenu> mSyncs2waysMenu;
+    QPointer<SyncsMenu> mBackupsMenu;
 
     MenuItemAction *exitActionGuest;
     MenuItemAction *settingsActionGuest;
@@ -419,48 +393,34 @@ protected:
     QTimer *scanningTimer;
 #endif
 
-    QTimer *connectivityTimer;
     std::unique_ptr<QTimer> onGlobalSyncStateChangedTimer;
     std::unique_ptr<QTimer> onDeferredPreferencesSyncTimer;
     QTimer proExpirityTimer;
     int scanningAnimationIndex;
-    SetupWizard *setupWizard;
-    SettingsDialog *settingsDialog;
-    InfoDialog *infoDialog;
-    Preferences *preferences;
-    Model *model;
-    Controller *controller;
+    QPointer<SettingsDialog> mSettingsDialog;
+    QPointer<InfoDialog> infoDialog;
+    std::shared_ptr<Preferences> preferences;
+    SyncInfo *model;
     mega::MegaApi *megaApi;
     mega::MegaApi *megaApiFolders;
     QFilterAlertsModel *notificationsProxyModel;
     QAlertsModel *notificationsModel;
     MegaAlertDelegate *notificationsDelegate;
-    std::unique_ptr<QObject> context{new QObject};
+    QObject *context;
     QString crashReportFilePath;
 
     HTTPServer *httpServer;
-    HTTPServer *httpsServer;
-    long long lastTsConnectionError = 0;
-    UploadToMegaDialog *uploadFolderSelector;
-    DownloadFromMegaDialog *downloadFolderSelector;
     mega::MegaHandle fileUploadTarget;
-    QFileDialog *fileUploadSelector;
     mega::MegaHandle folderUploadTarget;
-    QFileDialog *folderUploadSelector;
-    QPointer<StreamingFromMegaDialog> streamSelector;
-    MultiQFileDialog *multiUploadFileDialog;
+
     QQueue<QString> uploadQueue;
-    QQueue<mega::MegaNode *> downloadQueue;
+    QQueue<WrappedNode *> downloadQueue;
+    BlockingBatch mBlockingBatch;
+
     ThreadPool* mThreadPool;
     std::shared_ptr<mega::MegaNode> mRootNode;
-    std::shared_ptr<mega::MegaNode> mInboxNode;
+    std::shared_ptr<mega::MegaNode> mVaultNode;
     std::shared_ptr<mega::MegaNode> mRubbishNode;
-    bool mFetchingNodes = false;
-    bool mQueringWhyAmIBlocked = false;
-    int numTransfers[2];
-    int activeTransferTag[2];
-    unsigned long long activeTransferPriority[2];
-    unsigned int activeTransferState[2];
     bool queuedUserStats[3];
     int queuedStorageUserStatsReason;
     long long userStatsLastRequest[3];
@@ -475,25 +435,18 @@ protected:
     long long receivedStorageSum;
     long long maxMemoryUsage;
     int exportOps;
-    int syncState;
-    mega::MegaPricing *pricing;
-    UpgradeOverStorage *storageOverquotaDialog;
-    InfoWizard *infoWizard;
+    std::shared_ptr<mega::MegaPricing> mPricing;
+    std::shared_ptr<mega::MegaCurrency> mCurrency;
+    QPointer<UpgradeOverStorage> mStorageOverquotaDialog;
     mega::QTMegaListener *delegateListener;
     MegaUploader *uploader;
     MegaDownloader *downloader;
     QTimer *periodicTasksTimer;
+    QTimer *networkCheckTimer;
     QTimer *infoDialogTimer;
-    QTimer *firstTransferTimer;
     std::unique_ptr<std::thread> mMutexStealerThread;
 
     QTranslator translator;
-    PasteMegaLinksDialog *pasteMegaLinksDialog;
-    ChangeLogDialog *changeLogDialog;
-    ImportMegaLinksDialog *importDialog;
-    QMessageBox *exitDialog;
-    QMessageBox *sslKeyPinningError;
-    NodeSelector *downloadNodeSelector;
     QString lastTrayMessage;
     QStringList extraLinks;
     QString currentLanguageCode;
@@ -506,58 +459,159 @@ protected:
     QThread *updateThread;
     UpdateTask *updateTask;
     long long lastActiveTime;
-    QNetworkConfigurationManager networkConfigurationManager;
     QList<QNetworkInterface> activeNetworkInterfaces;
     QMap<QString, QString> pendingLinks;
     std::unique_ptr<MegaSyncLogger> logger;
-    QPointer<TransferManager> transferManager;
-    QMap<int, mega::MegaTransfer*> finishedTransfers;
-    QList<mega::MegaTransfer*> finishedTransferOrder;
-    QSet<int> finishedBlockedTransfers;
-
-    QHash<unsigned long long, TransferMetaData*> transferAppData;
+    QPointer<TransferManager> mTransferManager;
 
     bool reboot;
-    bool syncActive;
     bool paused;
-    bool indexing;
-    bool waiting;
-    bool syncing; //if any sync is in syncing state
+    bool mIndexing;
+    bool mWaiting;
+    bool mSyncing; //if any sync is in syncing state
+    bool mSyncStalled = false;
     bool updated;
-    bool transferring; //if there is any regular transfer in progress
+    bool mTransferring; //if there is any regular transfer in progress
     bool checkupdate;
     bool updateBlocked;
     long long lastExit;
     bool appfinished;
     bool updateAvailable;
     bool isLinux;
-    int noKeyDetected;
-    bool isFirstSyncDone;
-    bool isFirstFileSynced;
+    bool mIsFirstFileTwoWaySynced;
+    bool mIsFirstFileBackedUp;
     bool networkConnectivity;
-    int nUnviewedTransfers;
-    bool completedTabActive;
     int prevVersion;
     bool isPublic;
-    bool updatingSSLcert;
-    long long lastSSLcertUpdate;
     bool nodescurrent;
     int businessStatus = -2;
-    int blockState;
-    bool blockStateSet = false;
     bool whyamiblockedPeriodicPetition = false;
+    LoginController* mLoginController;
     friend class DeferPreferencesSyncForScope;
-    std::unique_ptr<TransferQuota> transferQuota;
+    std::shared_ptr<TransferQuota> mTransferQuota;
     bool transferOverQuotaWaitTimeExpiredReceived;
     std::shared_ptr<DesktopNotifications> mOsNotifications;
+    AccountStatusController* mStatusController;
     QMutex mMutexOpenUrls;
     QMap<QString, std::chrono::system_clock::time_point> mOpenUrlsClusterTs;
 
+    // Note: mSyncController is used only to add the syncs set up in the onboarding wizard
+    std::unique_ptr<SyncController> mSyncController;
+    LogoutController* mLogoutController;
+
+    QPointer<TransfersModel> mTransfersModel;
+
+    ScanStageController scanStageController;
+    std::shared_ptr<FolderTransferListener> mFolderTransferListener;
+
+    bool mDisableGfx;
+    StalledIssuesModel* mStalledIssuesModel;
+
 private:
-#ifdef _WIN32
-    std::shared_ptr<ShellNotifier> mShellNotifier;
-#endif
     void loadSyncExclusionRules(QString email = QString());
+
+    QList<QNetworkInterface> findNewNetworkInterfaces();
+    bool checkNetworkInterfaces(const QList<QNetworkInterface>& newNetworkInterfaces) const;
+    bool checkNetworkInterface(const QNetworkInterface& newNetworkInterface) const;
+    bool checkNetworkAddresses(const QNetworkInterface& oldNetworkInterface, const QNetworkInterface &newNetworkInterface) const;
+    bool checkIpAddress(const QHostAddress& ip, const QList<QNetworkAddressEntry>& oldAddresses, const QString& newNetworkInterfaceName) const;
+    static bool isActiveNetworkInterface(const QString& interfaceName, const QNetworkInterface::InterfaceFlags flags);
+    int countActiveIps(const QList<QNetworkAddressEntry>& addresses) const;
+    static bool isLocalIpv4(const QString& address);
+    static bool isLocalIpv6(const QString& address);
+    void logIpAddress(const char *message, const QHostAddress &ipAddress) const;
+
+    QString obfuscateIfNecessary(const QHostAddress& ipAddress) const;
+    static QString obfuscateAddress(const QHostAddress& ipAddress);
+    static QString obfuscateIpv4Address(const QHostAddress& ipAddress);
+    static QString obfuscateIpv6Address(const QHostAddress& ipAddress);
+    static QStringList explodeIpv6(const QHostAddress &ipAddress);
+
+    void reconnectIfNecessary(const bool disconnected, const QList<QNetworkInterface>& newNetworkInterfaces);
+    bool isIdleForTooLong() const;
+
+    void startUpload(const QString& rawLocalPath, mega::MegaNode* target, mega::MegaCancelToken *cancelToken);
+
+    void updateTransferNodesStage(mega::MegaTransfer* transfer);
+
+    void logBatchStatus(const char* tag);
+
+    void enableTransferActions(bool enable);
+
+    bool noUploadedStarted = true;
+    int mProcessingShellNotifications = 0;
+
+    void ConnectServerSignals(HTTPServer* server);
+
+    bool dontAskForExitConfirmation(bool force);
+    void exitApplication();
+
+    QString getDefaultUploadPath();
+
+    void checkSystemTray();
+
+    struct NodeCount
+    {
+        int files;
+        int folders;
+    };
+
+    BlockingStageProgressController transferProgressController;
+
+    static NodeCount countFilesAndFolders(const QStringList& paths);
+
+    void processUploads(const QStringList& uploads);
+
+    void updateMetadata(TransferMetaData* data, const QString& filePath);
+
+    template <class Func>
+    void recreateMenuAction(MenuItemAction** action, QMenu* menu, const QString& actionName,
+                            const char* iconPath, Func slotFunc)
+    {
+        bool previousEnabledState = true;
+        if (*action)
+        {
+            previousEnabledState = (*action)->isEnabled();
+            (*action)->deleteLater();
+            *action = nullptr;
+        }
+
+        *action = new MenuItemAction(actionName, QLatin1String(iconPath), menu);
+        (*action)->setManagesHoverStates(true);
+        connect(*action, &QAction::triggered, this, slotFunc, Qt::QueuedConnection);
+        (*action)->setEnabled(previousEnabledState);
+    }
+
+    template <class Func>
+    void recreateAction(QAction** action, QMenu* menu, const QString& actionName, Func slotFunc)
+    {
+        bool previousEnabledState = true;
+        if (*action)
+        {
+            previousEnabledState = (*action)->isEnabled();
+            (*action)->deleteLater();
+            *action = nullptr;
+        }
+
+        *action = new QAction(actionName, menu);
+        connect(*action, &QAction::triggered, this, slotFunc);
+        (*action)->setEnabled(previousEnabledState);
+    }
+
+    QQmlEngine* mEngine;
+
+    void processUpgradeSecurityEvent();
+    QQueue<QString> createQueue(const QStringList& newUploads) const;
+
+    void registerCommonQMLElements();
+    void addStyleSelector(const QStringList& args);
+
+private slots:
+    void onFolderTransferUpdate(FolderTransferUpdateEvent event);
+    void onNotificationProcessed();
+
+private:
+    QFutureWatcher<NodeCount> mWatcher;
 };
 
 class DeferPreferencesSyncForScope
@@ -581,15 +635,4 @@ public:
     }
 };
 
-class MEGASyncDelegateListener: public mega::QTMegaListener
-{
-public:
-    MEGASyncDelegateListener(mega::MegaApi *megaApi, mega::MegaListener *parent = NULL, MegaApplication *app = NULL);
-    void onRequestFinish(mega::MegaApi* api, mega::MegaRequest *request, mega::MegaError* e) override;
-    void onEvent(mega::MegaApi *api, mega::MegaEvent *e) override;
-
-protected:
-    MegaApplication *app;
-};
-
 #endif // MEGAAPPLICATION_H
