@@ -158,7 +158,7 @@ string getDistroVersion()
         oss << "Application: " << QApplication::applicationName().toUtf8().constData() << (sizeof(char*) == 4 ? " [32 bit]" : "") << (sizeof(char*) == 8 ? " [64 bit]" : "") << "\n";
         oss << "Version code: " << QString::number(Preferences::VERSION_CODE).toUtf8().constData() <<
                "." << QString::number(Preferences::BUILD_ID).toUtf8().constData() << "\n";
-        oss << "Module name: " << "megasync" << "\n";
+        oss << "Module name: " << MegaSyncApp->getMEGAString().toUtf8().constData() << "\n";
         oss << "Timestamp: " << QDateTime::currentMSecsSinceEpoch() << "\n";
 
         string distroinfo;
@@ -221,7 +221,11 @@ string getDistroVersion()
         {
             #if defined(__APPLE__)
                 ucontext_t* uc = (ucontext_t*) secret;
-                pnt = (void *)uc->uc_mcontext->__ss.__rip;
+                #if defined(__arm64__)
+                    pnt = (void *)uc->uc_mcontext->__ss.__pc;
+                #else
+                    pnt = (void *)uc->uc_mcontext->__ss.__rip;
+                #endif
             #elif defined(__x86_64__)
                 ucontext_t* uc = (ucontext_t*) secret;
                 pnt = (void*) uc->uc_mcontext.gregs[REG_RIP] ;
@@ -267,6 +271,18 @@ string getDistroVersion()
         write(dump_file, oss.str().c_str(), oss.str().size());
         close(dump_file);
 
+        struct sigaction sa;
+        sa.sa_handler = SIG_DFL;
+        sigemptyset (&sa.sa_mask);
+        sigaction(SIGSEGV, &sa, NULL);
+        sigaction(SIGBUS, &sa, NULL);
+        sigaction(SIGILL, &sa, NULL);
+        sigaction(SIGFPE, &sa, NULL);
+        sigaction(SIGABRT, &sa, NULL);
+#if defined(__arm64__)
+        sigaction(SIGTRAP, &sa, NULL);
+#endif
+
         CrashHandler::tryReboot();
         exit(128+sig);
     }
@@ -392,6 +408,11 @@ void CrashHandlerPrivate::InitCrashHandler(const QString& dumpPath)
         sigaction(SIGILL, &sa, NULL);
         sigaction(SIGFPE, &sa, NULL);
         sigaction(SIGABRT, &sa, NULL);
+// sigaction SIGTRAP for arm64 arch on macOS because in some cases such signal is emmited to indicate
+// unhandled exceptions in the program (e.g seg fault)
+#if defined(__APPLE__) && defined(__arm64__)
+        sigaction(SIGTRAP, &sa, NULL);
+#endif
         std::set_new_handler(mega_new_handler);
     #endif
 #endif
@@ -408,7 +429,8 @@ CrashHandler* CrashHandler::instance()
 
 void CrashHandler::tryReboot()
 {
-    Preferences *preferences = Preferences::instance();
+    auto preferences = Preferences::instance();
+    MegaApi::log(MegaApi::LOG_LEVEL_DEBUG, "Setting isCrashed true: tryReboot (CrashHandler)");
     preferences->setCrashed(true);
 
     if ((QDateTime::currentMSecsSinceEpoch()-preferences->getLastReboot()) > Preferences::MIN_REBOOT_INTERVAL_MS)
@@ -418,7 +440,7 @@ void CrashHandler::tryReboot()
 
 #ifndef __APPLE__
         QString app = MegaApplication::applicationFilePath();
-        QProcess::startDetached(app);
+        QProcess::startDetached(app, {});
 #else
         QString app = MegaApplication::applicationDirPath();
         QString launchCommand = QString::fromUtf8("open");
@@ -428,7 +450,7 @@ void CrashHandler::tryReboot()
         appPath.cdUp();
         appPath.cdUp();
 
-        args.append(QString::fromAscii("-n"));
+        args.append(QString::fromLatin1("-n"));
         args.append(appPath.absolutePath());
         QProcess::startDetached(launchCommand, args);
 #endif
@@ -481,7 +503,7 @@ bool CrashHandler::writeMinidump()
 
 QStringList CrashHandler::getPendingCrashReports()
 {
-    Preferences *preferences = Preferences::instance();
+    auto preferences = Preferences::instance();
     QStringList previousCrashes = preferences->getPreviousCrashes();
     QStringList result;
 
@@ -493,7 +515,7 @@ QStringList CrashHandler::getPendingCrashReports()
     for (int i = 0; i < fiList.size(); i++)
     {
         QFile file(fiList[i].absoluteFilePath());
-        if (!file.fileName().endsWith(QString::fromAscii(".dmp")))
+        if (!file.fileName().endsWith(QString::fromLatin1(".dmp")))
         {
             continue;
         }
@@ -511,18 +533,18 @@ QStringList CrashHandler::getPendingCrashReports()
         QString crashReport = QString::fromUtf8(file.readAll());
         file.close();
 
-        QStringList lines = crashReport.split(QString::fromAscii("\n"));
+        QStringList lines = crashReport.split(QString::fromLatin1("\n"));
         if ((lines.size()<3)
-                || (lines.at(0) != QString::fromAscii("MEGAprivate ERROR DUMP"))
-                || (!lines.at(1).startsWith(QString::fromAscii("Application: ") + QApplication::applicationName()))
-                || (!lines.at(2).startsWith(QString::fromAscii("Version code: ") + QString::number(Preferences::VERSION_CODE))))
+                || (lines.at(0) != QString::fromLatin1("MEGAprivate ERROR DUMP"))
+                || (!lines.at(1).startsWith(QString::fromLatin1("Application: ") + QApplication::applicationName()))
+                || (!lines.at(2).startsWith(QString::fromLatin1("Version code: ") + QString::number(Preferences::VERSION_CODE))))
         {
             MegaApi::log(MegaApi::LOG_LEVEL_WARNING, QString::fromUtf8("Invalid or outdated dump file: %1").arg(file.fileName()).toUtf8().constData());
             file.remove();
             continue;
         }
 
-        QString crashHash = QString::fromAscii(QCryptographicHash::hash(crashReport.toUtf8(),QCryptographicHash::Md5).toHex());
+        QString crashHash = QString::fromLatin1(QCryptographicHash::hash(crashReport.toUtf8(),QCryptographicHash::Md5).toHex());
         if (lastCrashHash.isNull())
         {
             lastCrashHash = crashHash;
@@ -532,7 +554,7 @@ QStringList CrashHandler::getPendingCrashReports()
         {
             MegaApi::log(MegaApi::LOG_LEVEL_INFO, QString::fromUtf8("New crash file: %1  Hash: %2")
                          .arg(file.fileName()).arg(crashHash).toUtf8().constData());
-            int idx = crashReport.indexOf(QString::fromAscii("Version code: "));
+            int idx = crashReport.indexOf(QString::fromLatin1("Version code: "));
             crashReport.insert(idx, QString::fromUtf8("Hash: %1\n").arg(crashHash));
             result.append(crashReport);
             previousCrashes.append(crashHash);
@@ -560,14 +582,14 @@ void CrashHandler::sendPendingCrashReports(QString userMessage)
     }
 
     crashes.append(userMessage);
-    QString postString = crashes.join(QString::fromAscii("------------------------------\n"));
-    postString.append(QString::fromAscii("\n------------------------------\n"));
+    QString postString = crashes.join(QString::fromLatin1("------------------------------\n"));
+    postString.append(QString::fromLatin1("\n------------------------------\n"));
 
     networkManager = new QNetworkAccessManager();
     connect(networkManager, SIGNAL(finished(QNetworkReply*)),
             this, SLOT(onPostFinished(QNetworkReply*)), Qt::UniqueConnection);
     request.setUrl(Preferences::CRASH_REPORT_URL);
-    request.setHeader(QNetworkRequest::ContentTypeHeader, QString::fromAscii("application/x-www-form-urlencoded"));
+    request.setHeader(QNetworkRequest::ContentTypeHeader, QString::fromLatin1("application/x-www-form-urlencoded"));
 
     MegaApi::log(MegaApi::LOG_LEVEL_INFO, "Sending crash reports");
     networkManager->post(request, postString.toUtf8());
@@ -576,12 +598,12 @@ void CrashHandler::sendPendingCrashReports(QString userMessage)
 
 void CrashHandler::discardPendingCrashReports()
 {
-    Preferences *preferences = Preferences::instance();
+    auto preferences = Preferences::instance();
     QStringList crashes = getPendingCrashReports();
     QStringList previousCrashes = preferences->getPreviousCrashes();
     for (int i = 0; i < crashes.size(); i++)
     {
-        QString crashHash = QString::fromAscii(QCryptographicHash::hash(crashes[i].toUtf8(),QCryptographicHash::Md5).toHex());
+        QString crashHash = QString::fromLatin1(QCryptographicHash::hash(crashes[i].toUtf8(),QCryptographicHash::Md5).toHex());
         if (!previousCrashes.contains(crashHash))
         {
             previousCrashes.append(crashHash);
@@ -632,7 +654,7 @@ void CrashHandler::deletePendingCrashReports()
     for (int i = 0; i < fiList.size(); i++)
     {
         QFileInfo fi = fiList[i];
-        if (fi.fileName().endsWith(QString::fromAscii(".dmp")))
+        if (fi.fileName().endsWith(QString::fromLatin1(".dmp")))
         {
             QFile::remove(fi.absoluteFilePath());
         }
