@@ -34,8 +34,8 @@
 #define LOG_TIME_CHARS 22
 #define LOG_LEVEL_CHARS 5
 
-#define MAX_FILESIZE_MB 10    // 10MB of log usually compresses to about 850KB (was 450 before duplicate line detection) 
-#define MAX_ROTATE_LOGS 50   // So we expect to keep 42MB or so in compressed logs
+#define MAX_LOG_FILESIZE_MB_DEFAULT 10    // 10MB of log usually compresses to about 850KB (was 450 before duplicate line detection)
+#define MAX_ROTATE_LOGS_DEFAULT 50   // So we expect to keep 42MB or so in compressed logs
 #define MAX_ROTATE_LOGS_TODELETE 50   // If ever reducing the number of logs, we should remove the older ones anyway. This number should be the historical maximum of that value
 
 
@@ -105,7 +105,7 @@ struct LogLinkedList
     static LogLinkedList* create(LogLinkedList* prev, size_t size)
     {
         LogLinkedList* entry = (LogLinkedList*)malloc(size);
-        if (entry) 
+        if (entry)
         {
             entry->next = nullptr;
             entry->allocated = unsigned(size - sizeof(LogLinkedList));
@@ -149,6 +149,7 @@ struct LogLinkedList
 };
 
 MegaSyncLogger *g_megaSyncLogger = nullptr;
+std::atomic<bool> gAppExit(false);
 
 struct LoggingThread
 {
@@ -193,6 +194,19 @@ private:
 
     void logThreadFunction(QString filename, QString desktopFilename)
     {
+        int logSizeBeforeCompressMb = MAX_LOG_FILESIZE_MB_DEFAULT;
+        if (auto mb = getenv("MEGA_MAX_LOG_FILESIZE_MB"))
+        {
+            logSizeBeforeCompressMb = atoi(mb);
+        }
+        int logCountToRotate = MAX_ROTATE_LOGS_DEFAULT;
+        int logCountToClean = MAX_ROTATE_LOGS_TODELETE;
+        if (auto count = getenv("MEGA_MAX_ROTATE_LOGS"))
+        {
+            logCountToRotate = atoi(count);
+            logCountToClean = std::max(logCountToRotate, logCountToClean);
+        }
+
     #ifdef WIN32
         std::ofstream outputFile(filename.toStdWString().data(), std::ofstream::out | std::ofstream::app);
     #else
@@ -208,7 +222,7 @@ private:
             if (forceRenew)
             {
                 std::lock_guard<std::mutex> g(logRotationMutex);
-                for (int i = MAX_ROTATE_LOGS_TODELETE; i--; )
+                for (int i = logCountToClean; i--; )
                 {
                     QString toDelete = numberedLogFilename(filename, i);
 
@@ -241,16 +255,16 @@ private:
                     emit g_megaSyncLogger->logCleaned();
                 }
             }
-            else if (forceRotationForReporting || outFileSize > MAX_FILESIZE_MB*1024*1024)
+            else if (forceRotationForReporting || outFileSize > logSizeBeforeCompressMb*1024*1024)
             {
                 std::lock_guard<std::mutex> g(logRotationMutex);
-                for (int i = MAX_ROTATE_LOGS_TODELETE; i--; )
+                for (int i = logCountToClean; i--; )
                 {
                     QString toRename = numberedLogFilename(filename, i);
 
                     if (QFile::exists(toRename))
                     {
-                        if (i + 1 >= MAX_ROTATE_LOGS)
+                        if (i + 1 >= logCountToRotate)
                         {
                             if (!QFile::remove(toRename))
                             {
@@ -279,7 +293,7 @@ private:
 
                 std::thread t([=]() {
                     std::lock_guard<std::mutex> g(logRotationMutex); // prevent another rotation while we work on this file (in case of unfortunate timing with bug report etc)
-                    gzipCompressOnRotate(newNameZipping, newNameDone); 
+                    gzipCompressOnRotate(newNameZipping, newNameDone);
                     if (report && g_megaSyncLogger)
                     {
                         emit g_megaSyncLogger->logReadyForReporting();
@@ -299,7 +313,7 @@ private:
             bool topLevelMemoryGap = false;
             {
                 std::unique_lock<std::mutex> lock(logMutex);
-                logConditionVariable.wait_for(lock, std::chrono::milliseconds(500), [this, &newMessages, &topLevelMemoryGap]() { 
+                logConditionVariable.wait_for(lock, std::chrono::milliseconds(500), [this, &newMessages, &topLevelMemoryGap]() {
                         if (forceRenew || logListFirst.next || logExit || forceRotationForReporting || logToDesktopChanged || flushLog || closeLog)
                         {
                             newMessages = logListFirst.next;
@@ -328,6 +342,7 @@ private:
                 else if (!logToDesktop && logDesktopFileOpen)
                 {
                     logDesktopFile.close();
+                    logDesktopFileOpen = false;
                 }
             }
 
@@ -377,7 +392,10 @@ private:
                             logDesktopFile << "<log gap - out of logging memory at this point>\n";
                         }
                     }
-                    logDesktopFile.flush(); //always flush in `active` logging
+                    if (!newMessages)
+                    {
+                        logDesktopFile.flush(); //always flush in `active` logging
+                    }
                 }
 
                 if (g_megaSyncLogger && g_megaSyncLogger->mLogToStdout)
@@ -390,7 +408,10 @@ private:
                     {
                         std::cout << p->message;
                     }
-                    std::cout << std::flush; //always flush into stdout (DEBUG mode)
+                    if (!newMessages)
+                    {
+                        std::cout << std::flush; //always flush into stdout (DEBUG mode)
+                    }
                 }
                 p->notifyWaiter();
                 free(p);
@@ -424,11 +445,16 @@ private:
 
 };
 
+void exitFunction()
+{
+    gAppExit = true;
+}
 
 MegaSyncLogger::MegaSyncLogger(QObject *parent, const QString& dataPath, const QString& desktopPath, bool logToStdout)
 : QObject{parent}
 , mDesktopPath{desktopPath}
 {
+    std::atexit(exitFunction);
     assert(!g_megaSyncLogger);
     g_megaSyncLogger = this;
     mLogToStdout = logToStdout;
@@ -444,12 +470,13 @@ MegaSyncLogger::MegaSyncLogger(QObject *parent, const QString& dataPath, const Q
     g_loggingThread->startLoggingThread(logPath, desktopLogPath);
 
     mega::MegaApi::setLogLevel(mega::MegaApi::LOG_LEVEL_MAX);
-    mega::MegaApi::addLoggerObject(this);
+    mega::MegaApi::addLoggerObject(this, true);
 }
 
 MegaSyncLogger::~MegaSyncLogger()
 {
-    mega::MegaApi::removeLoggerObject(this); // after this no more calls to MegaSyncLogger::log
+    // any other threads that might be logging have to be shut down before we call this
+    mega::MegaApi::removeLoggerObject(this, true);
 
     {
         std::lock_guard<std::mutex> g(g_loggingThread->logMutex);
@@ -464,8 +491,8 @@ MegaSyncLogger::~MegaSyncLogger()
 
 inline void twodigit(char*& s, int n)
 {
-    *s++ = n / 10 + '0';
-    *s++ = n % 10 + '0';
+    *s++ = static_cast<char>(n / 10 + '0');
+    *s++ = static_cast<char>(n % 10 + '0');
 }
 
 char* filltime(char* s, struct tm*  gmt, int microsec)
@@ -482,12 +509,13 @@ char* filltime(char* s, struct tm*  gmt, int microsec)
     *s++ = ':';
     twodigit(s, gmt->tm_sec);
     *s++ = '.';
-    s[5] = microsec % 10 + '0';
-    s[4] = (microsec /= 10) % 10 + '0';
-    s[3] = (microsec /= 10) % 10 + '0';
-    s[2] = (microsec /= 10) % 10 + '0';
-    s[1] = (microsec /= 10) % 10 + '0';
-    s[0] = (microsec /= 10) % 10 + '0';
+
+    s[5] = static_cast<char>(microsec % 10 + '0');
+    s[4] = static_cast<char>((microsec /= 10) % 10 + '0');
+    s[3] = static_cast<char>((microsec /= 10) % 10 + '0');
+    s[2] = static_cast<char>((microsec /= 10) % 10 + '0');
+    s[1] = static_cast<char>((microsec /= 10) % 10 + '0');
+    s[0] = static_cast<char>((microsec /= 10) % 10 + '0');
     s += 6;
     *s++ = ' ';
     *s = 0;
@@ -545,7 +573,6 @@ void MegaSyncLogger::log(const char*, int loglevel, const char*, const char *mes
 
 void LoggingThread::log(int loglevel, const char *message, const char **directMessages, size_t *directMessagesSizes, int numberMessages)
 {
-
 // todo: do we need this xml logger?
 //#ifdef LOG_TO_LOGGER
 //    //if (mConnected)
@@ -566,6 +593,11 @@ void LoggingThread::log(int loglevel, const char *message, const char **directMe
 //    }
 //#endif
 
+    if(gAppExit)
+    {
+        return;
+    }
+
     bool direct = directMessages != nullptr;
 
     char timebuf[LOG_TIME_CHARS + 1];
@@ -589,7 +621,7 @@ void LoggingThread::log(int loglevel, const char *message, const char **directMe
     case mega::MegaApi::LOG_LEVEL_DEBUG: loglevelstring = "DBG  "; break;
     case mega::MegaApi::LOG_LEVEL_MAX: loglevelstring = "DTL  "; break;
     }
-    
+
     auto messageLen = strlen(message);
     auto threadnameLen = strlen(threadname);
     auto lineLen = LOG_TIME_CHARS + threadnameLen + LOG_LEVEL_CHARS + messageLen;
@@ -599,7 +631,7 @@ void LoggingThread::log(int loglevel, const char *message, const char **directMe
         std::unique_ptr<std::lock_guard<std::mutex>> g(new std::lock_guard<std::mutex>(logMutex));
 
         bool isRepeat = !direct && logListLast != &logListFirst &&
-                        logListLast->lastmessage >= 0 && 
+                        logListLast->lastmessage >= 0 &&
                         !strncmp(message, logListLast->message + logListLast->lastmessage, messageLen);
 
         if (isRepeat)
@@ -615,6 +647,20 @@ void LoggingThread::log(int loglevel, const char *message, const char **directMe
                 logListLast->lastmessageRepeats = 0;
             }
 
+#if defined(WIN32) && defined(DEBUG)
+            OutputDebugStringA(std::string(timebuf).c_str());
+            OutputDebugStringA(std::string(threadname).c_str());
+            OutputDebugStringA(std::string(loglevelstring).c_str());
+            if (message)
+            {
+                OutputDebugStringA(std::string(message, messageLen).c_str());
+            }
+            for(int i = 0; i < numberMessages; i++)
+            {
+                OutputDebugStringA(std::string(directMessages[i], directMessagesSizes[i]).c_str());
+            }
+            OutputDebugStringA("\r\n");
+#endif
             if (direct)
             {
                 if (LogLinkedList* newentry = LogLinkedList::create(logListLast, 1 + sizeof(LogLinkedList))) //create a new "empty" element
@@ -687,10 +733,10 @@ void LoggingThread::log(int loglevel, const char *message, const char **directMe
             flushLog = true;
         }
     }
-    
+
     if (notify)
     {
-        // notify outside the mutex lock is better (and correct) for much less chance the other 
+        // notify outside the mutex lock is better (and correct) for much less chance the other
         // thread wakes up just to find the mutex locked. (saw lower cpu on the other thread like this)
         // Still, this notify call was taking 1% when notifying on every log line, so let the other thead
         // wake up by itself every 500ms without notify for the common case.
@@ -739,7 +785,7 @@ void MegaSyncLogger::flushAndClose()
     }
     catch (const std::exception& e)
     {
-        std::cerr << "Unhandle exception on flushAndClose: "<< e.what() << endl;
+        std::cerr << "Unhandle exception on flushAndClose: "<< e.what() << std::endl;
     }
     g_loggingThread->flushLog = true;
     g_loggingThread->closeLog = true;
