@@ -97,7 +97,7 @@ void UpdateTask::tryUpdate()
     QString randomSequence = QString::fromUtf8("?");
     for (int i = 0; i < 10; i++)
     {
-        randomSequence += QChar::fromAscii('A'+(rand() % 26));
+        randomSequence += QChar::fromLatin1(static_cast<char>('A'+ (rand() % 26)));
     }
 
     QString updateURL = Preferences::UPDATE_CHECK_URL;
@@ -208,8 +208,8 @@ void UpdateTask::downloadFile(QString url)
 QString UpdateTask::readNextLine(QNetworkReply *reply)
 {
     char line[4096];
-    int len = reply->readLine(line, sizeof(line));
-    if ((len <= 0) || ((unsigned int)(len - 1) >= sizeof(line)))
+    int len = static_cast<int>(reply->readLine(line, sizeof(line)));
+    if ((len <= 0) || (static_cast<unsigned int>(len - 1) >= sizeof(line)))
     {
         return QString();
     }
@@ -301,13 +301,13 @@ bool UpdateTask::processUpdateFile(QNetworkReply *reply)
 
         int intVersion = 0;
         QDir dataDir(preferences->getDataPath());
-        QString appVersionPath = dataDir.filePath(QString::fromAscii("megasync.version"));
+        QString appVersionPath = dataDir.filePath(QString::fromLatin1("megasync.version"));
         QFile f(appVersionPath);
         if (f.open(QFile::ReadOnly | QFile::Text))
         {
             QTextStream in(&f);
-            QString version = in.readAll();
-            intVersion = version.toInt();
+            QString versionIn = in.readAll();
+            intVersion = versionIn.toInt();
             if (intVersion > Preferences::VERSION_CODE)
             {
                 MegaApi::log(MegaApi::LOG_LEVEL_DEBUG, "External update detected");
@@ -344,7 +344,7 @@ bool UpdateTask::processFile(QNetworkReply *reply)
     //Create the folder for the new file
     QFile localFile(updateFolder.absoluteFilePath(localPaths[currentFile]));
     QFileInfo info(localFile);
-    info.absoluteDir().mkpath(QString::fromAscii("."));
+    info.absoluteDir().mkpath(QString::fromLatin1("."));
 
     //Delete the file if it exists.
     localFile.remove();
@@ -361,7 +361,7 @@ bool UpdateTask::processFile(QNetworkReply *reply)
     int position = 0;
     while (remainingSize)
     {
-        int written = localFile.write(data.constData()+position, remainingSize);
+        int written = static_cast<int>(localFile.write(data.constData()+position, remainingSize));
         if (written == -1)
         {
             MegaApi::log(MegaApi::LOG_LEVEL_ERROR, QString::fromUtf8("Error writting file: %1").arg(info.absoluteFilePath()).toUtf8().constData());
@@ -385,7 +385,7 @@ bool UpdateTask::processFile(QNetworkReply *reply)
 #ifdef _WIN32
     if (isPublic)
     {
-        Platform::makePubliclyReadable((LPTSTR)QDir::toNativeSeparators(localFile.fileName()).utf16());
+        Platform::getInstance()->makePubliclyReadable(QDir::toNativeSeparators(localFile.fileName()));
     }
 #endif
 
@@ -398,8 +398,8 @@ bool UpdateTask::performUpdate()
 
     //Create backup folder
     QDir basePathDir(basePath);
-    backupFolder = QDir(basePathDir.absoluteFilePath(Preferences::UPDATE_BACKUP_FOLDER_NAME + QDateTime::currentDateTime().toString(QString::fromAscii("_dd_MM_yy__hh_mm_ss"))));
-    backupFolder.mkdir(QString::fromAscii("."));
+    backupFolder = QDir(basePathDir.absoluteFilePath(Preferences::UPDATE_BACKUP_FOLDER_NAME + QDateTime::currentDateTime().toString(QString::fromLatin1("_dd_MM_yy__hh_mm_ss"))));
+    backupFolder.mkdir(QString::fromLatin1("."));
 
     for (int i = 0; i < localPaths.size(); i++)
     {
@@ -417,7 +417,7 @@ bool UpdateTask::performUpdate()
 #ifdef _WIN32
             if (isPublic)
             {
-                Platform::makePubliclyReadable((LPTSTR)QDir::toNativeSeparators(dstDir.absolutePath()).utf16());
+                Platform::getInstance()->makePubliclyReadable(QDir::toNativeSeparators(dstDir.absolutePath()));
             }
 #endif
         }
@@ -547,12 +547,12 @@ void UpdateTask::downloadFinished(QNetworkReply *reply)
     {
         if (!alreadyDownloaded(localPaths[currentFile], fileSignatures[currentFile]))
         {
-            MegaApi::log(MegaApi::LOG_LEVEL_INFO, QString::fromAscii("Downloading file: %1").arg(downloadURLs[currentFile]).toUtf8().constData());
+            MegaApi::log(MegaApi::LOG_LEVEL_INFO, QString::fromLatin1("Downloading file: %1").arg(downloadURLs[currentFile]).toUtf8().constData());
             downloadFile(downloadURLs[currentFile]);
             return;
         }
 
-        MegaApi::log(MegaApi::LOG_LEVEL_INFO, QString::fromAscii("File already downloaded: %1").arg(localPaths[currentFile]).toUtf8().constData());
+        MegaApi::log(MegaApi::LOG_LEVEL_INFO, QString::fromLatin1("File already downloaded: %1").arg(localPaths[currentFile]).toUtf8().constData());
         currentFile++;
     }
 
