@@ -1,8 +1,8 @@
 #ifndef ADDEXCLUSIONDIALOG_H
 #define ADDEXCLUSIONDIALOG_H
 
+#include "syncs/control/MegaIgnoreManager.h"
 #include <QDialog>
-#include "HighDpiResize.h"
 
 namespace Ui {
 class AddExclusionDialog;
@@ -13,7 +13,7 @@ class AddExclusionDialog : public QDialog
     Q_OBJECT
 
 public:
-    explicit AddExclusionDialog(QWidget *parent = 0);
+    explicit AddExclusionDialog(const QString& syncLocalFolder,QWidget *parent = 0);
     ~AddExclusionDialog();
     QString textValue();
 
@@ -29,8 +29,11 @@ protected:
     void changeEvent(QEvent * event);
 
 private:
+    void setTextToExclusionItem(const QString& path);
+    void addItem(const QStringList& selection);
+
     Ui::AddExclusionDialog *ui;
-    HighDpiResize highDpiResize;
+    QString mSyncLocalFolder;
 };
 
 #endif // ADDEXCLUSIONDIALOG_H
