@@ -1,7 +1,12 @@
 #include "AlertItem.h"
 #include "ui_AlertItem.h"
-#include <QDateTime>
+#include "CommonMessages.h"
 #include "MegaApplication.h"
+#include "UserAttributesRequests/FullName.h"
+#include <MegaNodeNames.h>
+#include "EmailRequester.h"
+
+#include <QDateTime>
 #include <QFutureWatcher>
 #include <QFuture>
 
@@ -13,26 +18,26 @@ using namespace mega;
 
 AlertItem::AlertItem(QWidget *parent) :
     QWidget(parent),
-    ui(new Ui::AlertItem)
+    ui(new Ui::AlertItem),
+    megaApi(MegaSyncApp->getMegaApi())
 {
     ui->setupUi(this);
-    megaApi = ((MegaApplication *)qApp)->getMegaApi();
 
     ui->sIconWidget->hide();
     ui->wNotificationIcon->hide();
     ui->lNew->hide();
 
-    connect(&getAlertNodeWatcher, &QFutureWatcher<void>::finished, this, [=](){
+    connect(&mAlertNodeWatcher, &QFutureWatcher<void>::finished, this, [=](){
 
-        alertNode.reset(static_cast<MegaNode*>(getAlertNodeWatcher.result()));
+        mAlertNode.reset(static_cast<MegaNode*>(mAlertNodeWatcher.result()));
 
-        setAlertType(alertUser->getType());
-        setAlertHeading(alertUser.get());
-        setAlertContent(alertUser.get());
-        setAlertTimeStamp(alertUser->getTimestamp(0));
-        alertUser->getSeen() ? ui->lNew->hide() : ui->lNew->show();
+        setAlertType(mAlertUser->getType());
+        setAlertHeading(mAlertUser.get());
+        setAlertContent(mAlertUser.get());
+        setAlertTimeStamp(mAlertUser->getTimestamp(0));
+        mAlertUser->getSeen() ? ui->lNew->hide() : ui->lNew->show();
 
-        emit refreshAlertItem(alertUser->getId());
+        emit refreshAlertItem(mAlertUser->getId());
         });
 }
 
@@ -43,12 +48,85 @@ AlertItem::~AlertItem()
 
 void AlertItem::setAlertData(MegaUserAlert *alert)
 {
-    alertUser.reset(alert->copy());
-    MegaHandle handle = alertUser->getNodeHandle();
-    getAlertNodeWatcher.setFuture(QtConcurrent::run([=]()
+    mAlertUser.reset(alert->copy());
+
+    if (alert->getUserHandle() != INVALID_HANDLE)
     {
-        return megaApi ? megaApi->getNodeByHandle(handle) : nullptr;
-    }));
+        if (alert->getEmail())
+        {
+            requestFullName(alert->getEmail());
+        }
+        else
+        {
+            requestEmail(alert);
+        }
+    }
+    else //If it comes without user handler, it is because is an own alert, then take your email.
+    {
+        if(megaApi)
+        {
+            ui->wAvatarContact->setUserEmail(megaApi->getMyEmail());
+        }
+    }
+
+    connect(ui->wAvatarContact, &AvatarWidget::avatarUpdated, this, [this](){
+        emit refreshAlertItem(mAlertUser->getId());
+    });
+
+    onAttributesReady();
+}
+
+void AlertItem::onUserEmailReady(QString email)
+{
+    requestFullName(email.toUtf8().constData());
+}
+
+void AlertItem::requestEmail(mega::MegaUserAlert* alert)
+{
+    EmailRequester* request = new EmailRequester(alert->getUserHandle());
+
+    connect(request, &EmailRequester::emailReceived, this, &AlertItem::onUserEmailReady, Qt::QueuedConnection);
+
+    request->requestEmail();
+}
+
+void AlertItem::requestFullName(const char* email)
+{
+    if (email != nullptr)
+    {
+        mFullNameAttributes = UserAttributes::FullName::requestFullName(email);
+
+        if(mFullNameAttributes)
+        {
+            connect(mFullNameAttributes.get(), &UserAttributes::FullName::fullNameReady, this, &AlertItem::onAttributesReady);
+        }
+
+        ui->wAvatarContact->setUserEmail(email);
+    }
+
+    onAttributesReady();
+}
+
+void AlertItem::onAttributesReady()
+{
+    MegaHandle handle = mAlertUser->getNodeHandle();
+
+    if (handle != INVALID_HANDLE)
+    {
+        mAlertNodeWatcher.setFuture(QtConcurrent::run([=]()
+        {
+            return megaApi ? megaApi->getNodeByHandle(handle) : nullptr;
+        }));
+    }
+    else
+    {
+        setAlertType(mAlertUser->getType());
+        setAlertHeading(mAlertUser.get());
+        setAlertContent(mAlertUser.get());
+        setAlertTimeStamp(mAlertUser->getTimestamp(0));
+        mAlertUser->getSeen() ? ui->lNew->hide() : ui->lNew->show();
+        emit refreshAlertItem(mAlertUser->getId());
+    }
 }
 
 void AlertItem::setAlertType(int type)
@@ -80,20 +158,21 @@ void AlertItem::setAlertType(int type)
             case MegaUserAlert::TYPE_DELETEDSHARE:
             case MegaUserAlert::TYPE_NEWSHAREDNODES:
             case MegaUserAlert::TYPE_REMOVEDSHAREDNODES:
+            case MegaUserAlert::TYPE_UPDATEDSHAREDNODES:
             {
                 if (type == MegaUserAlert::TYPE_DELETEDSHARE)
                 {
-                    ui->bSharedFolder->setIcon(QIcon(QString::fromUtf8(":/images/grey_folder.png")).pixmap(24.0, 24.0));
+                    ui->bSharedFolder->setIcon(QIcon(QString::fromUtf8(":/images/icons/folder/small-folder-disabled.png")).pixmap(24.0, 24.0));
                 }
                 else
                 {
-                    ui->bSharedFolder->setIcon(QIcon(QString::fromUtf8(":/images/color_folder.png")).pixmap(24.0, 24.0));
+                    ui->bSharedFolder->setIcon(QIcon(QString::fromUtf8(":/images/icons/folder/small-folder.png")).pixmap(24.0, 24.0));
                 }
 
                 ui->bNotificationIcon->setMinimumSize(QSize(10, 8));
                 ui->bNotificationIcon->setMaximumSize(QSize(10, 8));
                 ui->bNotificationIcon->setIconSize(QSize(10, 8));
-                ui->bNotificationIcon->setIcon(QIcon(QString::fromAscii("://images/share_arrow.png")));
+                ui->bNotificationIcon->setIcon(QIcon(QString::fromLatin1("://images/share_arrow.png")));
                 ui->wNotificationIcon->show();
                 notificationTitle = tr("Incoming Shares").toUpper();
                 notificationColor = QString::fromUtf8("#F2C249");
@@ -121,20 +200,20 @@ void AlertItem::setAlertType(int type)
                 ui->bNotificationIcon->setMinimumSize(QSize(16, 16));
                 ui->bNotificationIcon->setMaximumSize(QSize(16, 16));
                 ui->bNotificationIcon->setIconSize(QSize(16, 16));
-                ui->bNotificationIcon->setIcon(QIcon(QString::fromAscii("://images/mega_notifications.png")));
+                ui->bNotificationIcon->setIcon(QIcon(QString::fromLatin1("://images/mega_notifications.png")));
                 ui->wNotificationIcon->show();
             }
                 break;
     }
 
-    ui->lTitle->setStyleSheet(QString::fromAscii("#lTitle { font-family: Lato; font-weight: 900; font-size: 10px; color: %1; } ").arg(notificationColor));
+    ui->lTitle->setStyleSheet(QString::fromLatin1("#lTitle { font-family: Lato; font-weight: 900; font-size: 10px; color: %1; } ").arg(notificationColor));
     ui->lTitle->setText(notificationTitle);
 }
 
 void AlertItem::setAlertHeading(MegaUserAlert *alert)
 {
     ui->sIconWidget->hide();
-    notificationHeading.clear();
+    mNotificationHeading.clear();
 
     switch (alert->getType())
     {
@@ -143,8 +222,7 @@ void AlertItem::setAlertHeading(MegaUserAlert *alert)
         case MegaUserAlert::TYPE_INCOMINGPENDINGCONTACT_CANCELLED:
         case MegaUserAlert::TYPE_INCOMINGPENDINGCONTACT_REMINDER:
         {
-            setAvatar(alert);
-            notificationHeading = tr("New Contact Request");
+            mNotificationHeading = tr("New Contact Request");
             ui->sIconWidget->setCurrentWidget(ui->pContact);
             ui->sIconWidget->show();
             break;
@@ -152,24 +230,21 @@ void AlertItem::setAlertHeading(MegaUserAlert *alert)
         case MegaUserAlert::TYPE_CONTACTCHANGE_DELETEDYOU:
         case MegaUserAlert::TYPE_CONTACTCHANGE_ACCOUNTDELETED:
         {
-            setAvatar(alert);
-            notificationHeading = tr("Contact Deleted");
+            mNotificationHeading = tr("Contact Deleted");
             ui->sIconWidget->setCurrentWidget(ui->pContact);
             ui->sIconWidget->show();
             break;
         }
         case MegaUserAlert::TYPE_CONTACTCHANGE_CONTACTESTABLISHED:
         {
-            setAvatar(alert);
-            notificationHeading = tr("Contact Established");
+            mNotificationHeading = tr("Contact Established");
             ui->sIconWidget->setCurrentWidget(ui->pContact);
             ui->sIconWidget->show();
             break;
         }
         case MegaUserAlert::TYPE_CONTACTCHANGE_BLOCKEDYOU:
         {
-            setAvatar(alert);
-            notificationHeading = tr("Contact Blocked");
+            mNotificationHeading = tr("Contact Blocked");
             ui->sIconWidget->setCurrentWidget(ui->pContact);
             ui->sIconWidget->show();
             break;
@@ -178,24 +253,21 @@ void AlertItem::setAlertHeading(MegaUserAlert *alert)
         case MegaUserAlert::TYPE_UPDATEDPENDINGCONTACTINCOMING_ACCEPTED:
         case MegaUserAlert::TYPE_UPDATEDPENDINGCONTACTINCOMING_DENIED:
         {
-            setAvatar(alert);
-            notificationHeading = tr("Contact Updated");
+            mNotificationHeading = tr("Contact Updated");
             ui->sIconWidget->setCurrentWidget(ui->pContact);
             ui->sIconWidget->show();
             break;
         }
         case MegaUserAlert::TYPE_UPDATEDPENDINGCONTACTOUTGOING_ACCEPTED:
         {
-            setAvatar(alert);
-            notificationHeading = tr("Contact Accepted");
+            mNotificationHeading = tr("Contact Accepted");
             ui->sIconWidget->setCurrentWidget(ui->pContact);
             ui->sIconWidget->show();
             break;
         }
         case MegaUserAlert::TYPE_UPDATEDPENDINGCONTACTOUTGOING_DENIED:
         {
-            setAvatar(alert);
-            notificationHeading = tr("Contact Denied");
+            mNotificationHeading = tr("Contact Denied");
             ui->sIconWidget->setCurrentWidget(ui->pContact);
             ui->sIconWidget->show();
             break;
@@ -208,11 +280,23 @@ void AlertItem::setAlertHeading(MegaUserAlert *alert)
         {
             ui->sIconWidget->setCurrentWidget(ui->pSharedFolder);
             ui->sIconWidget->show();
-            notificationHeading = QString::fromUtf8(alertNode ? alertNode->getName() : alert->getName());
+            mNotificationHeading = MegaNodeNames::getNodeName(mAlertNode.get());
 
-            if (notificationHeading.isEmpty())
+            if (mNotificationHeading.isEmpty())
             {
-                notificationHeading = tr("Shared Folder Activity");
+                mNotificationHeading = tr("Shared Folder Activity");
+            }
+            break;
+        }
+        case MegaUserAlert::TYPE_UPDATEDSHAREDNODES:
+        {
+            ui->sIconWidget->setCurrentWidget(ui->pSharedFolder);
+            ui->sIconWidget->show();
+            mNotificationHeading = MegaNodeNames::getNodeName(mAlertNode.get());
+
+            if (mNotificationHeading.isEmpty())
+            {
+                mNotificationHeading = tr("Shared folder updated");
             }
             break;
         }
@@ -220,21 +304,28 @@ void AlertItem::setAlertHeading(MegaUserAlert *alert)
         case MegaUserAlert::TYPE_PAYMENT_SUCCEEDED:
         case MegaUserAlert::TYPE_PAYMENT_FAILED:
         case MegaUserAlert::TYPE_PAYMENTREMINDER:
-            notificationHeading = tr("Payment Info");
+            mNotificationHeading = tr("Payment Info");
             break;
         // Takedown notifications
         case MegaUserAlert::TYPE_TAKEDOWN:
         case MegaUserAlert::TYPE_TAKEDOWN_REINSTATED:
-            notificationHeading = tr("Takedown Notice");
+            mNotificationHeading = tr("Takedown Notice");
             break;
 
         default:
-            notificationHeading = tr("Notification");
+            mNotificationHeading = tr("Notification");
             break;
     }
 
+
     ui->lHeading->ensurePolished();
-    ui->lHeading->setText(ui->lHeading->fontMetrics().elidedText(notificationHeading, Qt::ElideMiddle,ui->lHeading->minimumWidth()));
+    ui->lHeading->setText(ui->lHeading->fontMetrics().elidedText(mNotificationHeading, Qt::ElideMiddle,ui->lHeading->minimumWidth()));
+
+    if(alert->getEmail())
+    {
+        mNotificationHeading.append(QString::fromLatin1(" (") + QString::fromUtf8(alert->getEmail()) + QString::fromLatin1(")"));
+        setToolTip(mNotificationHeading);
+    }
 }
 
 void AlertItem::setAlertContent(MegaUserAlert *alert)
@@ -245,30 +336,30 @@ void AlertItem::setAlertContent(MegaUserAlert *alert)
             // Contact notifications
             case MegaUserAlert::TYPE_INCOMINGPENDINGCONTACT_REQUEST:
                 notificationContent = tr("[A] sent you a contact request")
-                        .replace(QString::fromUtf8("[A]"), formatRichString(QString::fromUtf8(alert->getEmail())));
+                        .replace(QString::fromUtf8("[A]"), formatRichString(getUserFullName(alert)));
                 break;
             case MegaUserAlert::TYPE_INCOMINGPENDINGCONTACT_CANCELLED:
                 notificationContent = tr("[A] cancelled their contact request")
-                        .replace(QString::fromUtf8("[A]"), formatRichString(QString::fromUtf8(alert->getEmail())));
+                        .replace(QString::fromUtf8("[A]"), formatRichString(getUserFullName(alert)));
                 break;
             case MegaUserAlert::TYPE_INCOMINGPENDINGCONTACT_REMINDER:
-                notificationContent = tr("Reminder") + QString::fromUtf8(": ") + tr("You have a contact request");
+                notificationContent = tr("Reminder: You have a contact request");
                 break;
             case MegaUserAlert::TYPE_CONTACTCHANGE_DELETEDYOU:
                 notificationContent = tr("[A] deleted you as a contact")
-                        .replace(QString::fromUtf8("[A]"), formatRichString(QString::fromUtf8(alert->getEmail())));
+                        .replace(QString::fromUtf8("[A]"), formatRichString(getUserFullName(alert)));
                 break;
             case MegaUserAlert::TYPE_CONTACTCHANGE_ACCOUNTDELETED:
                 notificationContent = tr("[A] has been deleted/deactivated")
-                        .replace(QString::fromUtf8("[A]"), formatRichString(QString::fromUtf8(alert->getEmail())));
+                        .replace(QString::fromUtf8("[A]"), formatRichString(getUserFullName(alert)));
                 break;
             case MegaUserAlert::TYPE_CONTACTCHANGE_CONTACTESTABLISHED:
-                notificationContent = tr("[A] established you as a contact")
-                        .replace(QString::fromUtf8("[A]"), formatRichString(QString::fromUtf8(alert->getEmail())));
+                notificationContent = tr("[A] accepted your contact request")
+                        .replace(QString::fromUtf8("[A]"), formatRichString(getUserFullName(alert)));
                 break;
             case MegaUserAlert::TYPE_CONTACTCHANGE_BLOCKEDYOU:
                 notificationContent = tr("[A] blocked you as contact")
-                        .replace(QString::fromUtf8("[A]"), formatRichString(QString::fromUtf8(alert->getEmail())));
+                        .replace(QString::fromUtf8("[A]"), formatRichString(getUserFullName(alert)));
                 break;
             case MegaUserAlert::TYPE_UPDATEDPENDINGCONTACTINCOMING_IGNORED:
                 notificationContent = tr("You ignored a contact request");
@@ -281,27 +372,27 @@ void AlertItem::setAlertContent(MegaUserAlert *alert)
                 break;
             case MegaUserAlert::TYPE_UPDATEDPENDINGCONTACTOUTGOING_ACCEPTED:
                 notificationContent = tr("[A] accepted your contact request")
-                        .replace(QString::fromUtf8("[A]"), formatRichString(QString::fromUtf8(alert->getEmail())));
+                        .replace(QString::fromUtf8("[A]"), formatRichString(getUserFullName(alert)));
                 break;
             case MegaUserAlert::TYPE_UPDATEDPENDINGCONTACTOUTGOING_DENIED:
                 notificationContent = tr("[A] denied your contact request")
-                        .replace(QString::fromUtf8("[A]"), formatRichString(QString::fromUtf8(alert->getEmail())));
+                        .replace(QString::fromUtf8("[A]"), formatRichString(getUserFullName(alert)));
                 break;
             // Share notifications
             case MegaUserAlert::TYPE_NEWSHARE:
-                notificationContent = tr("New Shared folder from [X]")
-                        .replace(QString::fromUtf8("[X]"), formatRichString(QString::fromUtf8(alert->getEmail())));
+                notificationContent = tr("New shared folder from [A]")
+                        .replace(QString::fromUtf8("[A]"), formatRichString(getUserFullName(alert)));
                 break;
             case MegaUserAlert::TYPE_DELETEDSHARE:
             {
                 if (alert->getNumber(0) == 0) //Someone left the folder
                 {
                     notificationContent = tr("[A] has left the shared folder")
-                            .replace(QString::fromUtf8("[A]"), formatRichString(QString::fromUtf8(alert->getEmail())));
+                            .replace(QString::fromUtf8("[A]"), formatRichString(getUserFullName(alert)));
                 }
                 else //Access for the user was removed by share owner
                 {
-                    notificationContent = alert->getEmail() ? tr("Access to shared folder was removed by [A]").replace(QString::fromUtf8("[A]"), formatRichString(QString::fromUtf8(alert->getEmail())))
+                    notificationContent = alert->getEmail() ? tr("Access to shared folder was removed by [A]").replace(QString::fromUtf8("[A]"), formatRichString(getUserFullName(alert)))
                                                             : tr("Access to shared folder was removed");
                 }
                 break;
@@ -310,33 +401,22 @@ void AlertItem::setAlertContent(MegaUserAlert *alert)
             case MegaUserAlert::TYPE_NEWSHAREDNODES:
             {
                 int64_t updatedItems = alert->getNumber(1) + alert->getNumber(0);
-                if (updatedItems == 1)
-                {
-                    notificationContent = tr("[A] added 1 item")
-                            .replace(QString::fromUtf8("[A]"), formatRichString(QString::fromUtf8(alert->getEmail())));
-                }
-                else
-                {
-                    notificationContent = tr("[A] added [B] items")
-                            .replace(QString::fromUtf8("[A]"), formatRichString(QString::fromUtf8(alert->getEmail())))
-                            .replace(QString::fromUtf8("[B]"), QString::number(updatedItems));
-                }
+                notificationContent = tr("[A] added %n item", "", static_cast<int>(updatedItems))
+                        .replace(QString::fromUtf8("[A]"), formatRichString(getUserFullName(alert)));
                 break;
             }
             case MegaUserAlert::TYPE_REMOVEDSHAREDNODES:
             {
                 int64_t updatedItems = alert->getNumber(0);
-                if (updatedItems == 1)
-                {
-                    notificationContent = tr("[A] removed 1 item")
-                            .replace(QString::fromUtf8("[A]"), formatRichString(QString::fromUtf8(alert->getEmail())));
-                }
-                else
-                {
-                    notificationContent = tr("[A] removed [B] items")
-                            .replace(QString::fromUtf8("[A]"), formatRichString(QString::fromUtf8(alert->getEmail())))
-                            .replace(QString::fromUtf8("[B]"), QString::number(updatedItems));
-                }
+                notificationContent = tr("[A] removed %n item", "", static_cast<int>(updatedItems))
+                        .replace(QString::fromUtf8("[A]"), formatRichString(getUserFullName(alert)));
+                break;
+            }
+            case MegaUserAlert::TYPE_UPDATEDSHAREDNODES:
+            {
+                int64_t updatedItems = alert->getNumber(0);
+                notificationContent = tr("[A] updated %n item", "", static_cast<int>(updatedItems))
+                        .replace(QString::fromUtf8("[A]"), formatRichString(getUserFullName(alert)));
                 break;
             }
             // Payment notifications
@@ -350,49 +430,23 @@ void AlertItem::setAlertContent(MegaUserAlert *alert)
                 break;
             case MegaUserAlert::TYPE_PAYMENTREMINDER:
             {
-                QDateTime expiredDate;
-                expiredDate.setMSecsSinceEpoch(alert->getTimestamp(1) * 1000);
-                QDateTime currentDate(QDateTime::currentDateTime());
-
-                int daysExpired = currentDate.daysTo(expiredDate);
-                if (daysExpired == 1)
-                {
-                    notificationContent = tr("Your PRO membership plan will expire in 1 day");
-                }
-                else if (daysExpired > 0)
-                {
-                    notificationContent = tr("Your PRO membership plan will expire in [A] days")
-                            .replace(QString::fromUtf8("[A]"), formatRichString(QString::number(daysExpired)));
-                }
-                else if (daysExpired == 0)
-                {
-                    notificationContent = tr("PRO membership plan expiring soon");
-                }
-                else if (daysExpired == -1)
-                {
-                    notificationContent = tr("Your PRO membership plan expired 1 day ago");
-                }
-                else
-                {
-                    notificationContent = tr("Your PRO membership plan expired [A] days ago")
-                            .replace(QString::fromUtf8("[A]"), formatRichString(QString::number(-daysExpired)));
-                }
+                notificationContent = CommonMessages::createPaymentReminder(alert->getTimestamp(1));
                 break;
             }
             // Takedown notifications
             case MegaUserAlert::TYPE_TAKEDOWN:
             {
-                if (alertNode)
+                if (mAlertNode)
                 {
-                    if (alertNode->getType() == MegaNode::TYPE_FILE)
+                    if (mAlertNode->getType() == MegaNode::TYPE_FILE)
                     {
                         notificationContent = tr("Your publicly shared file ([A]) has been taken down")
-                                .replace(QString::fromUtf8("[A]"), formatRichString(QString::fromUtf8(alertNode->getName())));
+                                .replace(QString::fromUtf8("[A]"), formatRichString(MegaNodeNames::getNodeName(mAlertNode.get())));
                     }
-                    else if (alertNode->getType() == MegaNode::TYPE_FOLDER)
+                    else if (mAlertNode->getType() == MegaNode::TYPE_FOLDER)
                     {
                         notificationContent = tr("Your publicly shared folder ([A]) has been taken down")
-                                .replace(QString::fromUtf8("[A]"), formatRichString(QString::fromUtf8(alertNode->getName())));
+                                .replace(QString::fromUtf8("[A]"), formatRichString(MegaNodeNames::getNodeName(mAlertNode.get())));
                     }
                     else
                     {
@@ -407,17 +461,17 @@ void AlertItem::setAlertContent(MegaUserAlert *alert)
             }
             case MegaUserAlert::TYPE_TAKEDOWN_REINSTATED:
             {
-                if (alertNode)
+                if (mAlertNode)
                 {
-                    if (alertNode->getType() == MegaNode::TYPE_FILE)
+                    if (mAlertNode->getType() == MegaNode::TYPE_FILE)
                     {
                         notificationContent = tr("Your publicly shared file ([A]) has been reinstated")
-                                .replace(QString::fromUtf8("[A]"), formatRichString(QString::fromUtf8(alertNode->getName())));
+                                .replace(QString::fromUtf8("[A]"), formatRichString(MegaNodeNames::getNodeName(mAlertNode.get())));
                     }
-                    else if (alertNode->getType() == MegaNode::TYPE_FOLDER)
+                    else if (mAlertNode->getType() == MegaNode::TYPE_FOLDER)
                     {
                         notificationContent = tr("Your publicly shared folder ([A]) has been reinstated")
-                                .replace(QString::fromUtf8("[A]"), formatRichString(QString::fromUtf8(alertNode->getName())));
+                                .replace(QString::fromUtf8("[A]"), formatRichString(MegaNodeNames::getNodeName(mAlertNode.get())));
                     }
                     else
                     {
@@ -442,70 +496,56 @@ void AlertItem::setAlertTimeStamp(int64_t ts)
 {
     if (ts != -1)
     {
-        QString dateTimeFormat;
         const QDateTime dateTime{QDateTime::fromMSecsSinceEpoch(ts * 1000)};
-        const bool sameYear(dateTime.date().year() == QDateTime::currentDateTime().date().year());
-        const bool sameWeek{QDateTime::currentDateTime().date().weekNumber() == dateTime.date().weekNumber()};
-
-        if(sameWeek && sameYear)
-        {
-            dateTimeFormat.append(QStringLiteral("dddd, "));
-        }
-        dateTimeFormat.append(QStringLiteral("d MMMM "));
-
-        if(!sameYear)
-        {
-            dateTimeFormat.append(QStringLiteral("yyyy "));
-        }
-
-        const QString language{static_cast<MegaApplication*>(qApp)->getCurrentLanguageCode()};
-        dateTimeFormat.append(QLocale(language).timeFormat(QLocale::ShortFormat));
-        const QString dateTimeTranslated{QLocale(language).toString(dateTime, dateTimeFormat)};
-        ui->lTimeStamp->setText(dateTimeTranslated);
+        ui->lTimeStamp->setText(MegaSyncApp->getFormattedDateByCurrentLanguage(dateTime));
     }
     else
     {
         ui->lTimeStamp->setText(QString::fromUtf8(""));
     }
-
 }
 
 QString AlertItem::getHeadingString()
 {
-    return notificationHeading;
+    return mNotificationHeading;
 }
 
 QSize AlertItem::minimumSizeHint() const
 {
     return QSize(400, 122);
 }
+
 QSize AlertItem::sizeHint() const
 {
     return QSize(400, 122);
 }
 
-void AlertItem::setAvatar(MegaUserAlert *alert)
+void AlertItem::changeEvent(QEvent *event)
 {
-    QString color;
-    const char* avatarColor = megaApi->getUserAvatarColor(megaApi->handleToBase64(qHash(QString::fromUtf8(alert->getEmail()))));
-
-    if (avatarColor)
+    if (event->type() == QEvent::LanguageChange)
     {
-        color = QString::fromUtf8(avatarColor);
-        delete [] avatarColor;
+        ui->retranslateUi(this);
+        setAlertType(mAlertUser->getType());
+        setAlertHeading(mAlertUser.get());
+        setAlertContent(mAlertUser.get());
+        setAlertTimeStamp(mAlertUser->getTimestamp(0));
     }
-
-    QString fullname = QString::fromUtf8(alert->getEmail());
-    if (fullname.isEmpty())
-    {
-        fullname = QString::fromUtf8("C");
-    }
-
-    ui->wAvatarContact->setAvatarLetter(fullname.at(0).toUpper(), color);
+    QWidget::changeEvent(event);
 }
 
 QString AlertItem::formatRichString(QString str)
 {
-    return QString::fromUtf8("<span style='color:#333333; font-family: Lato; font-size: 14px; font-weight: bold; text-decoration:none;'><bold>%1</bold></span>")
+    return QString::fromUtf8("<span style='color:#333333; font-family: Lato; font-size: 14px; font-weight: bold; text-decoration:none;'>%1</span>")
             .arg(str);
 }
+
+QString AlertItem::getUserFullName(MegaUserAlert *alert)
+{
+    if(mFullNameAttributes)
+    {
+        return mFullNameAttributes->getRichFullName();
+    }
+
+    return QString::fromUtf8(alert->getEmail());
+}
+
