@@ -2,14 +2,20 @@
 #define ALERTITEM_H
 
 #include <QWidget>
-#include "megaapi.h"
 #include <QFutureWatcher>
+
 #include <memory>
 
+#include "megaapi.h"
+
 namespace Ui {
 class AlertItem;
 }
 
+namespace UserAttributes{
+class FullName;
+}
+
 class AlertItem : public QWidget
 {
     Q_OBJECT
@@ -23,6 +29,7 @@ public:
     void setAlertHeading(mega::MegaUserAlert *alert);
     void setAlertContent(mega::MegaUserAlert *alert);
     void setAlertTimeStamp(int64_t ts);
+    void onUserEmailReady(QString email);
 
     QString getHeadingString();
 
@@ -32,17 +39,26 @@ public:
 signals:
     void refreshAlertItem(unsigned item);
 
+protected:
+    void changeEvent(QEvent *event);
+
+private slots:
+    void onAttributesReady();
+
 private:
-    void setAvatar(mega::MegaUserAlert *alert);
     QString formatRichString(QString str);
+    QString getUserFullName(mega::MegaUserAlert *alert);
+    void requestFullName(const char* email);
+    void requestEmail(mega::MegaUserAlert* alert);
 
 private:
     Ui::AlertItem *ui;
     mega::MegaApi *megaApi;
-    QString notificationHeading;
-    std::unique_ptr<mega::MegaNode> alertNode;
-    std::unique_ptr<mega::MegaUserAlert> alertUser;
-    QFutureWatcher<mega::MegaNode*> getAlertNodeWatcher;
+    QString mNotificationHeading;
+    std::unique_ptr<mega::MegaNode> mAlertNode;
+    std::unique_ptr<mega::MegaUserAlert> mAlertUser;
+    std::shared_ptr<const UserAttributes::FullName> mFullNameAttributes;
+    QFutureWatcher<mega::MegaNode*> mAlertNodeWatcher;
 };
 
 #endif // ALERTITEM_H
