@@ -1,9 +1,8 @@
 #ifndef CHANGELOGDIALOG_H
 #define CHANGELOGDIALOG_H
 
-#include "control/Preferences.h"
+#include "control/Preferences/Preferences.h"
 #include <QDialog>
-#include "HighDpiResize.h"
 
 namespace Ui {
 class ChangeLogDialog;
@@ -19,7 +18,6 @@ public:
 
 private:
     Ui::ChangeLogDialog *ui;
-    HighDpiResize highDpiResize;
 
     void setChangeLogNotes(QString notes);
 
@@ -31,7 +29,6 @@ private slots:
     void on_bTerms_clicked();
     void on_bPolicy_clicked();
     void on_bAck_clicked();
-    void on_bGDPR_clicked();
 };
 
 #endif // CHANGELOGDIALOG_H
