@@ -11,12 +11,12 @@ class FilterAlertWidget;
 class FilterAlertWidget : public QWidget
 {
     Q_OBJECT
-
+    static const int RED_BUBBLE_MARGIN;
 public:
     explicit FilterAlertWidget(QWidget *parent = 0);
     ~FilterAlertWidget();
 
-    void setUnseenNotifications(int all = 0, int contacts = 0, int shares = 0, int payment = 0);
+    void setUnseenNotifications(long long all = 0, long long contacts = 0, long long shares = 0, long long payment = 0);
     void reset();
 
 private slots:
@@ -30,6 +30,9 @@ signals:
 
 private:
     Ui::FilterAlertWidget *ui;
+
+protected:
+    void changeEvent(QEvent *event);
 };
 
 #endif // FILTERALERTWIDGET_H
