@@ -5,19 +5,20 @@
 #include <QStringList>
 #include "megaapi.h"
 #include "control/LinkProcessor.h"
-#include "control/Preferences.h"
-#include "HighDpiResize.h"
+#include "control/Preferences/Preferences.h"
 
 namespace Ui {
 class ImportMegaLinksDialog;
 }
 
+class UploadNodeSelector;
+
 class ImportMegaLinksDialog : public QDialog
 {
     Q_OBJECT
 
 public:
-    explicit ImportMegaLinksDialog(mega::MegaApi *megaApi, Preferences *preferences, LinkProcessor *linkProcessor, QWidget *parent = 0);
+    explicit ImportMegaLinksDialog(LinkProcessor* linkProcessor, QWidget *parent = 0);
     ~ImportMegaLinksDialog();
 
     bool shouldImport();
@@ -30,6 +31,7 @@ private slots:
     void on_cImport_clicked();
     void on_bLocalFolder_clicked();
     void on_bMegaFolder_clicked();
+    void on_bOk_clicked();
 
 public slots:
     void onLinkInfoAvailable(int id);
@@ -37,19 +39,34 @@ public slots:
     void onLinkStateChanged(int id, int state);
 
 protected:
-    void changeEvent(QEvent * event);
+    void changeEvent(QEvent * event) override;
 
 private:
     Ui::ImportMegaLinksDialog *ui;
-    mega::MegaApi *megaApi;
-    LinkProcessor *linkProcessor;
-    bool finished;
-    HighDpiResize highDpiResize;
+    mega::MegaApi *mMegaApi;
+    std::shared_ptr<Preferences> mPreferences;
+    LinkProcessor* mLinkProcessor;
+    bool mFinished;
+
+    bool mDownloadPathChangedByUser;
+
+    bool mUseDefaultImportPath;
+    bool mImportPathChangedByUser;
+
+    void initUiAsLogged();
+    void initUiAsUnlogged();
+    void initImportFolderControl();
+    void setInvalidImportFolder();
 
     void enableOkButton() const;
     void enableLocalFolder(bool enable);
     void enableMegaFolder(bool enable);
     void checkLinkValidAndSelected();
+
+    void onLocalFolderSet(const QString& path);
+
+    void updateDownloadPath();
+    void updateImportPath(const QString& path = QString());
 };
 
 #endif // IMPORTMEGALINKSDIALOG_H
