@@ -5,6 +5,7 @@
 #include "control/AppStatsEvents.h"
 #include "control/CrashHandler.h"
 #include "ScaleFactorManager.h"
+#include "PowerOptions.h"
 
 #include <QFontDatabase>
 #include <assert.h>
@@ -42,23 +43,29 @@ std::vector<LogMessage> logMessages;
 
 void msgHandler(QtMsgType type, const char *msg)
 {
-    switch (type) {
-    case QtDebugMsg:
-        MegaApi::log(MegaApi::LOG_LEVEL_DEBUG, QString::fromUtf8("QT Debug: %1").arg(QString::fromUtf8(msg)).toUtf8().constData());
-        break;
-    case QtWarningMsg:
-        MegaApi::log(MegaApi::LOG_LEVEL_WARNING, QString::fromUtf8("QT Warning: %1").arg(QString::fromUtf8(msg)).toUtf8().constData());
-        break;
-    case QtCriticalMsg:
-        MegaApi::log(MegaApi::LOG_LEVEL_ERROR, QString::fromUtf8("QT Critical: %1").arg(QString::fromUtf8(msg)).toUtf8().constData());
-        break;
-    case QtFatalMsg:
-        MegaApi::log(MegaApi::LOG_LEVEL_FATAL, QString::fromUtf8("QT FATAL ERROR: %1").arg(QString::fromUtf8(msg)).toUtf8().constData());
-        break;
+    switch (type)
+    {
+        case QtInfoMsg:
+            MegaApi::log(MegaApi::LOG_LEVEL_INFO, QString::fromUtf8("Qt Info: %1").arg(QString::fromUtf8(msg)).toUtf8().constData());
+            break;
+        case QtDebugMsg:
+            MegaApi::log(MegaApi::LOG_LEVEL_DEBUG, QString::fromUtf8("Qt Debug: %1").arg(QString::fromUtf8(msg)).toUtf8().constData());
+            break;
+        case QtWarningMsg:
+            MegaApi::log(MegaApi::LOG_LEVEL_WARNING, QString::fromUtf8("Qt Warning: %1").arg(QString::fromUtf8(msg)).toUtf8().constData());
+            break;
+        case QtCriticalMsg:
+            MegaApi::log(MegaApi::LOG_LEVEL_ERROR, QString::fromUtf8("Qt Critical: %1").arg(QString::fromUtf8(msg)).toUtf8().constData());
+            break;
+        case QtFatalMsg:
+            MegaApi::log(MegaApi::LOG_LEVEL_FATAL, QString::fromUtf8("Qt FATAL: %1").arg(QString::fromUtf8(msg)).toUtf8().constData());
+            break;
+        default:
+            MegaApi::log(MegaApi::LOG_LEVEL_MAX, QString::fromUtf8("Qt MSG: %1").arg(QString::fromUtf8(msg)).toUtf8().constData());
+            break;
     }
 }
 
-
 #ifdef Q_OS_LINUX
 MegaApplication *theapp = NULL;
 bool waitForRestartSignal = false;
@@ -85,65 +92,77 @@ void LinuxSignalHandler(int signum)
 
         if (theapp)
         {
-            theapp->exitApplication(true);
+            theapp->tryExitApplication(true);
         }
     }
 }
 
 #endif
 
-#if QT_VERSION >= 0x050000
     void messageHandler(QtMsgType type,const QMessageLogContext &context, const QString &msg)
     {
-        switch (type) {
-        case QtDebugMsg:
-            MegaApi::log(MegaApi::LOG_LEVEL_DEBUG, QString::fromUtf8("QT Debug: %1").arg(msg).toUtf8().constData());
-            MegaApi::log(MegaApi::LOG_LEVEL_DEBUG, QString::fromUtf8("QT Context: %1 %2 %3 %4 %5")
-                         .arg(QString::fromUtf8(context.category))
-                         .arg(QString::fromUtf8(context.file))
-                         .arg(QString::fromUtf8(context.function))
-                         .arg(QString::fromUtf8(context.file))
-                         .arg(context.version).toUtf8().constData());
-            break;
-        case QtWarningMsg:
-            MegaApi::log(MegaApi::LOG_LEVEL_WARNING, QString::fromUtf8("QT Warning: %1").arg(msg).toUtf8().constData());
-            MegaApi::log(MegaApi::LOG_LEVEL_WARNING, QString::fromUtf8("QT Context: %1 %2 %3 %4 %5")
-                         .arg(QString::fromUtf8(context.category))
-                         .arg(QString::fromUtf8(context.file))
-                         .arg(QString::fromUtf8(context.function))
-                         .arg(QString::fromUtf8(context.file))
-                         .arg(context.version).toUtf8().constData());
-            break;
-        case QtCriticalMsg:
-            MegaApi::log(MegaApi::LOG_LEVEL_ERROR, QString::fromUtf8("QT Critical: %1").arg(msg).toUtf8().constData());
-            MegaApi::log(MegaApi::LOG_LEVEL_ERROR, QString::fromUtf8("QT Context: %1 %2 %3 %4 %5")
-                         .arg(QString::fromUtf8(context.category))
-                         .arg(QString::fromUtf8(context.file))
-                         .arg(QString::fromUtf8(context.function))
-                         .arg(QString::fromUtf8(context.file))
-                         .arg(context.version).toUtf8().constData());
-            break;
-        case QtFatalMsg:
-            MegaApi::log(MegaApi::LOG_LEVEL_FATAL, QString::fromUtf8("QT FATAL ERROR: %1").arg(msg).toUtf8().constData());
-            MegaApi::log(MegaApi::LOG_LEVEL_FATAL, QString::fromUtf8("QT Context: %1 %2 %3 %4 %5")
-                         .arg(QString::fromUtf8(context.category))
-                         .arg(QString::fromUtf8(context.file))
-                         .arg(QString::fromUtf8(context.function))
-                         .arg(QString::fromUtf8(context.file))
-                         .arg(context.version).toUtf8().constData());
-            break;
+        switch (type)
+        {
+            case QtInfoMsg:
+                MegaApi::log(MegaApi::LOG_LEVEL_INFO, QString::fromUtf8("Qt Info: %1").arg(msg).toUtf8().constData());
+                // deliberately not showing context for Info level
+                break;
+            case QtDebugMsg:
+                MegaApi::log(MegaApi::LOG_LEVEL_DEBUG, QString::fromUtf8("Qt Debug: %1").arg(msg).toUtf8().constData());
+                MegaApi::log(MegaApi::LOG_LEVEL_DEBUG, QString::fromUtf8("Qt Context: %1 %2 %3 %4 %5")
+                             .arg(QString::fromUtf8(context.category))
+                             .arg(QString::fromUtf8(context.file))
+                             .arg(QString::fromUtf8(context.function))
+                             .arg(QString::fromUtf8(context.file))
+                             .arg(context.version).toUtf8().constData());
+                break;
+            case QtWarningMsg:
+                MegaApi::log(MegaApi::LOG_LEVEL_WARNING, QString::fromUtf8("Qt Warning: %1").arg(msg).toUtf8().constData());
+                MegaApi::log(MegaApi::LOG_LEVEL_WARNING, QString::fromUtf8("Qt Context: %1 %2 %3 %4 %5")
+                             .arg(QString::fromUtf8(context.category))
+                             .arg(QString::fromUtf8(context.file))
+                             .arg(QString::fromUtf8(context.function))
+                             .arg(QString::fromUtf8(context.file))
+                             .arg(context.version).toUtf8().constData());
+                break;
+            case QtCriticalMsg:
+                MegaApi::log(MegaApi::LOG_LEVEL_ERROR, QString::fromUtf8("Qt Critical: %1").arg(msg).toUtf8().constData());
+                MegaApi::log(MegaApi::LOG_LEVEL_ERROR, QString::fromUtf8("Qt Context: %1 %2 %3 %4 %5")
+                             .arg(QString::fromUtf8(context.category))
+                             .arg(QString::fromUtf8(context.file))
+                             .arg(QString::fromUtf8(context.function))
+                             .arg(QString::fromUtf8(context.file))
+                             .arg(context.version).toUtf8().constData());
+                break;
+            case QtFatalMsg:
+                MegaApi::log(MegaApi::LOG_LEVEL_FATAL, QString::fromUtf8("Qt FATAL: %1").arg(msg).toUtf8().constData());
+                MegaApi::log(MegaApi::LOG_LEVEL_FATAL, QString::fromUtf8("Qt Context: %1 %2 %3 %4 %5")
+                             .arg(QString::fromUtf8(context.category))
+                             .arg(QString::fromUtf8(context.file))
+                             .arg(QString::fromUtf8(context.function))
+                             .arg(QString::fromUtf8(context.file))
+                             .arg(context.version).toUtf8().constData());
+                break;
+           default:
+                MegaApi::log(MegaApi::LOG_LEVEL_MAX, QString::fromUtf8("Qt MSG: %1").arg(msg).toUtf8().constData());
+                MegaApi::log(MegaApi::LOG_LEVEL_MAX, QString::fromUtf8("Qt Context: %1 %2 %3 %4 %5")
+                             .arg(QString::fromUtf8(context.category))
+                             .arg(QString::fromUtf8(context.file))
+                             .arg(QString::fromUtf8(context.function))
+                             .arg(QString::fromUtf8(context.file))
+                             .arg(context.version).toUtf8().constData());
+                break;
         }
     }
-#endif
 
 void removeSyncData(const QString &localFolder, const QString & name, const QString &syncID)
 {
-    Platform::syncFolderRemoved(localFolder, name, syncID);
+    Platform::getInstance()->syncFolderRemoved(localFolder, name, syncID);
 
     #ifdef WIN32
     // unhide debris folder
     QString debrisPath = QDir::toNativeSeparators(localFolder +
-            QDir::separator() + QString::fromAscii(MEGA_DEBRIS_FOLDER));
+            QDir::separator() + QString::fromUtf8(MEGA_DEBRIS_FOLDER));
 
     WIN32_FILE_ATTRIBUTE_DATA fad;
     if (GetFileAttributesExW((LPCWSTR)debrisPath.utf16(), GetFileExInfoStandard, &fad))
@@ -165,15 +184,48 @@ void removeSyncData(const QString &localFolder, const QString & name, const QStr
     #endif
 }
 
+void freeStaticResources()
+{
+    PowerOptions::appShutdown();
+    Platform::destroy();
+}
+
+void addFonts()
+{
+#if !defined(__APPLE__) && !defined (_WIN32)
+    QFontDatabase::addApplicationFont(QString::fromUtf8("://fonts/OpenSans-Regular.ttf"));
+    QFontDatabase::addApplicationFont(QString::fromUtf8("://fonts/OpenSans-Semibold.ttf"));
+
+    QFont font(QString::fromUtf8("Open Sans"), 8);
+    theapp->setFont(font);
+#endif
+
+    QFontDatabase::addApplicationFont(QString::fromUtf8("://fonts/SourceSansPro-Semibold.ttf"));
+
+    QFontDatabase::addApplicationFont(QString::fromUtf8("://fonts/Lato-Light.ttf"));
+    QFontDatabase::addApplicationFont(QString::fromUtf8("://fonts/Lato-Bold.ttf"));
+    QFontDatabase::addApplicationFont(QString::fromUtf8("://fonts/Lato-Regular.ttf"));
+    QFontDatabase::addApplicationFont(QString::fromUtf8("://fonts/Lato-Semibold.ttf"));
+}
+
 int main(int argc, char *argv[])
 {
-    QCoreApplication::setOrganizationName(QString::fromAscii("Mega Limited"));
-    QCoreApplication::setOrganizationDomain(QString::fromAscii("mega.co.nz"));
-    QCoreApplication::setApplicationName(QString::fromAscii("MEGAsync"));
+    QCoreApplication::setOrganizationName(QString::fromUtf8("Mega Limited"));
+    QCoreApplication::setOrganizationDomain(QString::fromUtf8("mega.co.nz"));
+    QCoreApplication::setApplicationName(QString::fromUtf8("MEGAsync")); //Do not change app name, keep MEGAsync because Linux rely on that for app paths.
+    QCoreApplication::setApplicationVersion(QString::number(Preferences::VERSION_CODE));
+
+    Platform::create();
+
+    // This call is responsible for rebuilding the Qt symlinks in platforms where it applies.
+    // This needs to be done when starting the first time after an update.
+    // For this to work, the call needs to know the version of the app BEFORE updating,
+    // so needs to be made before the file megasync.version is updated.
+    Platform::getInstance()->processSymLinks();
 
     if ((argc == 2) && !strcmp("/uninstall", argv[1]))
     {
-        Preferences *preferences = Preferences::instance();
+        auto preferences = Preferences::instance();
         preferences->initialize(MegaApplication::applicationDataPath());
         if (!preferences->error())
         {
@@ -190,7 +242,7 @@ int main(int argc, char *argv[])
                 QList<SyncData> syncData = preferences->readOldCachedSyncs();
                 foreach(SyncData osd, syncData)
                 {
-                    removeSyncData(osd.mLocalFolder, osd.mName.remove(QChar::fromAscii(':')), osd.mSyncID);
+                    removeSyncData(osd.mLocalFolder, osd.mName.remove(QLatin1Char(':')), osd.mSyncID);
                 }
 
                 // now for the new syncs cached configurations
@@ -205,12 +257,12 @@ int main(int argc, char *argv[])
         }
 
         Utilities::removeRecursively(MegaApplication::applicationDataPath());
-        Platform::uninstall();
+        Platform::getInstance()->uninstall();
 
 #ifdef WIN32
         if (preferences->installationTime() != -1)
         {
-            MegaApi *megaApi = new MegaApi(Preferences::CLIENT_KEY, (char *)NULL, Preferences::USER_AGENT);
+            MegaApi *megaApi = new MegaApi(Preferences::CLIENT_KEY, (char *)NULL, Preferences::USER_AGENT.toUtf8().constData());
             QString stats = QString::fromUtf8("{\"it\":%1,\"act\":%2,\"lt\":%3}")
                     .arg(preferences->installationTime())
                     .arg(preferences->accountCreationTime())
@@ -224,10 +276,11 @@ int main(int argc, char *argv[])
                 base64stats.resize(base64stats.size() - 1);
             }
 
-            megaApi->sendEvent(AppStatsEvents::EVENT_INSTALL_STATS, base64stats.constData());
+            megaApi->sendEvent(AppStatsEvents::EVENT_INSTALL_STATS, base64stats.constData(), false, nullptr);
             Sleep(5000);
         }
 #endif
+        freeStaticResources();
         return 0;
     }
 
@@ -272,9 +325,11 @@ int main(int argc, char *argv[])
 
                 bool success = QProcess::startDetached(app);
                 cout << "Restarting MEGAsync: " << app.toUtf8().constData() << " " << (success?"OK":"FAILED!") << endl;
+                freeStaticResources();
                 exit(!success);
             }
             cout << "Timed out waiting for restart signal" << endl;
+            freeStaticResources();
             exit(2);
         }
     }
@@ -325,14 +380,6 @@ int main(int argc, char *argv[])
             qputenv("QT_PLUGIN_PATH","/opt/mega/plugins");
         }
     }
-
-    if (!(getenv("DO_NOT_OVERRIDE_XDG_CURRENT_DESKTOP")))
-    {
-        if (getenv("XDG_CURRENT_DESKTOP") && !strcmp(getenv("XDG_CURRENT_DESKTOP"),"KDE") && (!getenv("XDG_SESSION_TYPE") || strcmp(getenv("XDG_SESSION_TYPE"),"wayland") ) )
-        {
-            qputenv("XDG_CURRENT_DESKTOP","GNOME");
-        }
-    }
 #endif
 
 #if defined(Q_OS_LINUX) && QT_VERSION >= 0x050C00
@@ -389,7 +436,6 @@ int main(int argc, char *argv[])
     }
 #endif
 
-
     MegaApplication app(argc, argv);
 #if defined(Q_OS_LINUX)
     theapp = &app;
@@ -402,11 +448,20 @@ int main(int argc, char *argv[])
     }
 #endif
 
-    for(const auto message : logMessages)
+    for(const auto &message : logMessages)
     {
         MegaApi::log(message.logLevel, message.message.toStdString().c_str());
     }
 
+#ifdef Q_OS_LINUX
+    auto megaLibGL = getenv("MEGA_LIBGL_ALWAYS_SOFTWARE");
+    if (megaLibGL && !strcmp(megaLibGL, "1"))
+    {
+        MegaApi::log(MegaApi::LOG_LEVEL_INFO, "Setting LIBGL_ALWAYS_SOFTWARE to 1");
+        qputenv("LIBGL_ALWAYS_SOFTWARE", "1");
+    }
+#endif
+
 #ifndef Q_OS_MACX
     const auto scaleFactorLogMessages = scaleFactorManager.getLogMessages();
     for(const auto& message : scaleFactorLogMessages)
@@ -424,16 +479,16 @@ int main(int argc, char *argv[])
     }
 #endif
 
-    qInstallMsgHandler(msgHandler);
-#if QT_VERSION >= 0x050000
     qInstallMessageHandler(messageHandler);
-#endif
 
     app.setStyle(new MegaProxyStyle());
 
 #ifdef Q_OS_MACX
 
-    MegaApi::log(MegaApi::LOG_LEVEL_INFO, QString::fromUtf8("Running on macOS version: %1").arg(QString::number(QSysInfo::MacintoshVersion)).toUtf8().constData());
+    auto current = QOperatingSystemVersion::current();
+    MegaApi::log(MegaApi::LOG_LEVEL_INFO, QString::fromUtf8("Running on macOS version: %1.%2.%3")
+                 .arg(current.majorVersion()).arg(current.minorVersion()).arg(current.microVersion())
+                 .toUtf8().constData());
 
     if (!harfbuzzEnabled)
     {
@@ -445,31 +500,24 @@ int main(int argc, char *argv[])
         MegaApi::log(MegaApi::LOG_LEVEL_WARNING, "Error setting QT_SSL_USE_TEMPORARY_KEYCHAIN vble");
     }
 
-    if (QSysInfo::MacintoshVersion > QSysInfo::MV_10_8)
-    {
-        // fix Mac OS X 10.9 (mavericks) font issue
-        // https://bugreports.qt-project.org/browse/QTBUG-32789
-        QFont::insertSubstitution(QString::fromUtf8(".Lucida Grande UI"), QString::fromUtf8("Lucida Grande"));
-    }
-
     app.setAttribute(Qt::AA_UseHighDpiPixmaps);
 #endif
 
     QDir dataDir(app.applicationDataPath());
-    QString crashPath = dataDir.filePath(QString::fromAscii("crashDumps"));
-    QString avatarPath = dataDir.filePath(QString::fromAscii("avatars"));
-    QString appLockPath = dataDir.filePath(QString::fromAscii("megasync.lock"));
-    QString appShowPath = dataDir.filePath(QString::fromAscii("megasync.show"));
+    QString crashPath = dataDir.filePath(QString::fromUtf8("crashDumps"));
+    QString avatarPath = dataDir.filePath(QString::fromUtf8("avatars"));
+    QString appLockPath = dataDir.filePath(QString::fromUtf8("megasync.lock"));
+    QString appShowPath = dataDir.filePath(QString::fromUtf8("megasync.show"));
     QDir crashDir(crashPath);
     if (!crashDir.exists())
     {
-        crashDir.mkpath(QString::fromAscii("."));
+        crashDir.mkpath(QString::fromUtf8("."));
     }
 
     QDir avatarsDir(avatarPath);
     if (!avatarsDir.exists())
     {
-        avatarsDir.mkpath(QString::fromAscii("."));
+        avatarsDir.mkpath(QString::fromUtf8("."));
     }
 
 #ifndef DEBUG
@@ -514,7 +562,7 @@ int main(int argc, char *argv[])
 #ifdef __APPLE__
         else if (i == 5)
         {
-            QString appVersionPath = dataDir.filePath(QString::fromAscii("megasync.version"));
+            QString appVersionPath = dataDir.filePath(QString::fromUtf8("megasync.version"));
             QFile fappVersionPath(appVersionPath);
             if (!fappVersionPath.exists())
             {
@@ -530,7 +578,9 @@ int main(int argc, char *argv[])
         #endif
     }
 
-    QString appVersionPath = dataDir.filePath(QString::fromAscii("megasync.version"));
+    // The megasync.version file update needs to be done AFTER Platform::getInstance()->processSymLinks(),
+    // because it needs the old version number.
+    QString appVersionPath = dataDir.filePath(QString::fromUtf8("megasync.version"));
     QFile fappVersionPath(appVersionPath);
     if (fappVersionPath.open(QIODevice::WriteOnly))
     {
@@ -541,32 +591,35 @@ int main(int argc, char *argv[])
     if (alreadyStarted)
     {
         MegaApi::log(MegaApi::LOG_LEVEL_WARNING, "MEGAsync is already started");
+        freeStaticResources();
         return 0;
     }
-    Platform::initialize(argc, argv);
+    Platform::getInstance()->initialize(argc, argv);
 
-#if !defined(__APPLE__) && !defined (_WIN32)
-    QFontDatabase::addApplicationFont(QString::fromAscii("://fonts/OpenSans-Regular.ttf"));
-    QFontDatabase::addApplicationFont(QString::fromAscii("://fonts/OpenSans-Semibold.ttf"));
+    addFonts();
 
-    QFont font(QString::fromAscii("Open Sans"), 8);
-    app.setFont(font);
-#endif
-    QFontDatabase::addApplicationFont(QString::fromAscii("://fonts/SourceSansPro-Light.ttf"));
-    QFontDatabase::addApplicationFont(QString::fromAscii("://fonts/SourceSansPro-Bold.ttf"));
-    QFontDatabase::addApplicationFont(QString::fromAscii("://fonts/SourceSansPro-Regular.ttf"));
-    QFontDatabase::addApplicationFont(QString::fromAscii("://fonts/SourceSansPro-Semibold.ttf"));
+    QFontDatabase::addApplicationFont(QString::fromUtf8("://fonts/Inter-Bold.ttf"));
+    QFontDatabase::addApplicationFont(QString::fromUtf8("://fonts/Inter-Black.ttf"));
+    QFontDatabase::addApplicationFont(QString::fromUtf8("://fonts/Inter-ExtraBold.ttf"));
+    QFontDatabase::addApplicationFont(QString::fromUtf8("://fonts/Inter-ExtraLight.ttf"));
+    QFontDatabase::addApplicationFont(QString::fromUtf8("://fonts/Inter-Light.ttf"));
+    QFontDatabase::addApplicationFont(QString::fromUtf8("://fonts/Inter-Medium.ttf"));
+    QFontDatabase::addApplicationFont(QString::fromUtf8("://fonts/Inter-Regular.ttf"));
+    QFontDatabase::addApplicationFont(QString::fromUtf8("://fonts/Inter-SemiBold.ttf"));
+    QFontDatabase::addApplicationFont(QString::fromUtf8("://fonts/Inter-Thin.ttf"));
 
-    QFontDatabase::addApplicationFont(QString::fromAscii("://fonts/Lato-Light.ttf"));
-    QFontDatabase::addApplicationFont(QString::fromAscii("://fonts/Lato-Bold.ttf"));
-    QFontDatabase::addApplicationFont(QString::fromAscii("://fonts/Lato-Regular.ttf"));
-    QFontDatabase::addApplicationFont(QString::fromAscii("://fonts/Lato-Semibold.ttf"));
+    app.setWindowIcon(QIcon(QString::fromUtf8(":/images/app_ico.ico")));
 
     app.initialize();
     app.start();
 
     int toret = app.exec();
 
+    freeStaticResources();
+#ifdef WIN32
+    extern bool WindowsPlatform_exiting;
+    WindowsPlatform_exiting = true;
+#endif
 
 #ifdef Q_OS_LINUX
     theapp = nullptr;
@@ -653,7 +706,6 @@ int main(int argc, char *argv[])
     QT_TRANSLATE_NOOP("QFileSystemModel", "Date Modified");
     QT_TRANSLATE_NOOP("QFileSystemModel", "My Computer");
     QT_TRANSLATE_NOOP("QFileSystemModel", "Computer");
-    QT_TRANSLATE_NOOP("QFileSystemModel", "%1 byte(s)");
 
     QT_TRANSLATE_NOOP("Installer", "Choose Users");
     QT_TRANSLATE_NOOP("Installer", "Choose for which users you want to install $(^NameDA).");
@@ -680,6 +732,7 @@ int main(int argc, char *argv[])
     QT_TRANSLATE_NOOP("MegaError", "Incomplete");
     QT_TRANSLATE_NOOP("MegaError", "Invalid key/Decryption error");
     QT_TRANSLATE_NOOP("MegaError", "Bad session ID");
+    QT_TRANSLATE_NOOP("MegaError", "File removed as it violated our Terms of Service");
     QT_TRANSLATE_NOOP("MegaError", "Blocked");
     QT_TRANSLATE_NOOP("MegaError", "Over quota");
     QT_TRANSLATE_NOOP("MegaError", "Temporarily not available");
@@ -690,19 +743,17 @@ int main(int argc, char *argv[])
     QT_TRANSLATE_NOOP("MegaError", "SSL verification failed");
     QT_TRANSLATE_NOOP("MegaError", "Not enough quota");
     QT_TRANSLATE_NOOP("MegaError", "Unknown error");
-    QT_TRANSLATE_NOOP("MegaError", "Your account has been suspended due to multiple breaches of MEGA’s Terms of Service. Please check your email inbox.");
-    QT_TRANSLATE_NOOP("MegaError", "Your account was terminated due to breach of Mega’s Terms of Service, such as abuse of rights of others; sharing and/or importing illegal data; or system abuse.");
+    QT_TRANSLATE_NOOP("MegaError", "Your account has been suspended due to copyright violations. Please check your email inbox.");
+    QT_TRANSLATE_NOOP("MegaError", "Your account was terminated due to a breach of MEGA's Terms of Service, such as abuse of rights of others; sharing and/or importing illegal data; or system abuse.");
     QT_TRANSLATE_NOOP("MegaError", "Storage Quota Exceeded. Upgrade now");
+    QT_TRANSLATE_NOOP("MegaError", "Decryption error");
     QT_TRANSLATE_NOOP("FinderExtensionApp", "Get MEGA link");
     QT_TRANSLATE_NOOP("FinderExtensionApp", "View on MEGA");
     QT_TRANSLATE_NOOP("FinderExtensionApp", "No options available");
     QT_TRANSLATE_NOOP("FinderExtensionApp", "Click the toolbar item for a menu.");
-    QT_TRANSLATE_NOOP("FinderExtensionApp", "1 file");
-    QT_TRANSLATE_NOOP("FinderExtensionApp", "%i files");
-    QT_TRANSLATE_NOOP("FinderExtensionApp", "1 folder");
-    QT_TRANSLATE_NOOP("FinderExtensionApp", "%i folders");
+    QT_TRANSLATE_NOOP("FinderExtensionApp", "%n file", "", n);
+    QT_TRANSLATE_NOOP("FinderExtensionApp", "%n folder", "", n);
     QT_TRANSLATE_NOOP("FinderExtensionApp", "View previous versions");
-    QT_TRANSLATE_NOOP("MegaNodeNames", "Cloud Drive");
     QT_TRANSLATE_NOOP("MegaSyncError", "No error");
     QT_TRANSLATE_NOOP("MegaSyncError", "Unknown error");
     QT_TRANSLATE_NOOP("MegaSyncError", "File system not supported");
@@ -713,7 +764,7 @@ int main(int argc, char *argv[])
     QT_TRANSLATE_NOOP("MegaSyncError", "Local path not available");
     QT_TRANSLATE_NOOP("MegaSyncError", "Remote node not found");
     QT_TRANSLATE_NOOP("MegaSyncError", "Reached storage quota limit");
-    QT_TRANSLATE_NOOP("MegaSyncError", "Business account expired");
+    QT_TRANSLATE_NOOP("MegaSyncError", "Your plan has expired");
     QT_TRANSLATE_NOOP("MegaSyncError", "Foreign target storage quota reached");
     QT_TRANSLATE_NOOP("MegaSyncError", "Remote path has changed");
     QT_TRANSLATE_NOOP("MegaSyncError", "Remote node moved to Rubbish Bin");
