@@ -4,8 +4,8 @@
 #include <QCoreApplication>
 #include <QWidget>
 #include <QProcess>
-#include <Preferences.h>
-#import "platform/macx/NSPopover+MISSINGBackgroundView.h"
+#include <Preferences/Preferences.h>
+#include <QOperatingSystemVersion>
 
 #import <objc/runtime.h>
 #import <sys/proc_info.h>
@@ -15,10 +15,6 @@
 #include <errno.h>
 #include <sys/sysctl.h>
 
-#ifndef kCFCoreFoundationVersionNumber10_9
-    #define kCFCoreFoundationVersionNumber10_9 855.00
-#endif
-
 // A NSViewController that controls a programatically created view
 @interface ProgramaticViewController : NSViewController
 @end
@@ -78,311 +74,113 @@ QStringList qt_mac_NSArrayToQStringList(void *nsarray)
     return result;
 }
 
-QStringList uploadMultipleFiles(QString uploadTitle)
+
+void selectorsImpl(QString title, QString defaultDir, bool multiSelection, bool showFiles, bool showFolders, bool createDirectories, QWidget *parent, std::function<void (QStringList)> func)
 {
     QStringList uploads;
-    static NSOpenPanel *panel = NULL;
+
+    if(panel)
+    {
+        auto panelParentWindow = [panel sheetParent];
+        if(panelParentWindow)
+        {
+            [panelParentWindow endSheet: panel];
+        }
+        else
+        {
+            [panel close];
+            panel = NULL;
+        }
+    }
 
     if (!panel)
     {
         panel = [NSOpenPanel openPanel];
-        [panel setTitle:[NSString stringWithUTF8String:uploadTitle.toUtf8().constData()]];
-        [panel setCanChooseFiles:YES];
-        [panel setCanChooseDirectories:YES];
-        [panel setAllowsMultipleSelection:YES];
-
-        NSInteger clicked = [panel runModal];
-        if (clicked == NSFileHandlingPanelOKButton)
+        if(!parent)
         {
-            uploads = qt_mac_NSArrayToQStringList([panel URLs]);
+            [panel setTitle:[NSString stringWithUTF8String:title.toUtf8().constData()]];
+        }
+        [panel setCanChooseFiles: showFiles ? YES : NO];
+        [panel setCanChooseDirectories:showFolders ? YES : NO];
+        [panel setAllowsMultipleSelection:multiSelection ? YES : NO];
+        [panel setCanCreateDirectories: createDirectories ? YES : NO];
+
+        if(!defaultDir.isEmpty())
+        {
+            NSURL *baseURL = [NSURL fileURLWithPath:[NSString stringWithUTF8String:defaultDir.toUtf8().constData()]];
+            [panel setDirectoryURL:baseURL];
         }
 
-        panel = NULL;
-        return uploads;
+        if(parent)
+        {
+            NSView* nsview = (__bridge NSView*)reinterpret_cast<void*>(parent->window()->winId());
+            NSWindow *nswindow = [nsview window];
+            [panel beginSheetModalForWindow: nswindow
+                                             completionHandler:^(NSInteger result) {
+                QStringList selection;
+                if(result  == NSFileHandlingPanelOKButton)
+                {
+                    selection = qt_mac_NSArrayToQStringList([panel URLs]);
+                }
+                func(selection);
+                panel = NULL;
+            }];
+        }
+        else
+        {
+            [panel beginWithCompletionHandler:^(NSInteger result){
+                QStringList selection;
+                if(result  == NSFileHandlingPanelOKButton)
+                {
+                    selection = qt_mac_NSArrayToQStringList([panel URLs]);
+                }
+                func(selection);
+                panel = NULL;
+            }];
+        }
+        raiseFileSelectionPanels();
     }
-
-    return QStringList();
 }
 
-// Copyright (c) 2011 The Chromium Authors. All rights reserved.
-// Use of this source code is governed by a BSD-style license that can be
-// found in the LICENSE file.
-void SetProcessName(QString procname)
+void raiseFileSelectionPanels()
 {
-    CFStringRef process_name = CFStringCreateWithCString(NULL, procname.toUtf8().constData(), kCFStringEncodingUTF8);
-    if (!process_name || CFStringGetLength(process_name) == 0)
+    if(panel)
     {
-        if (process_name)
-        {
-            CFRelease(process_name);
-        }
-        return;
+        [panel orderFrontRegardless];
     }
-
-    if (![NSThread isMainThread])
-    {
-        CFRelease(process_name);
-        return;
-    }
-
-    typedef CFTypeRef PrivateLSASN;
-    typedef PrivateLSASN (*LSGetCurrentApplicationASNType)();
-    typedef OSStatus (*LSSetApplicationInformationItemType)(int, PrivateLSASN,
-                                                          CFStringRef,
-                                                          CFStringRef,
-                                                          CFDictionaryRef*);
-
-    static LSGetCurrentApplicationASNType ls_get_current_application_asn_func = NULL;
-    static LSSetApplicationInformationItemType ls_set_application_information_item_func = NULL;
-    static CFStringRef ls_display_name_key = NULL;
-
-    CFStringRef* key_pointer;
-    ProcessSerialNumber psn;
-
-    static bool did_symbol_lookup = false;
-    if (!did_symbol_lookup)
-    {
-        did_symbol_lookup = true;
-        CFBundleRef launch_services_bundle = CFBundleGetBundleWithIdentifier(CFSTR("com.apple.LaunchServices"));
-        if (!launch_services_bundle)
-        {
-            CFRelease(process_name);
-            return;
-        }
-
-        ls_get_current_application_asn_func =
-            reinterpret_cast<LSGetCurrentApplicationASNType>(
-                CFBundleGetFunctionPointerForName(
-                    launch_services_bundle, CFSTR("_LSGetCurrentApplicationASN")));
-
-        ls_set_application_information_item_func =
-            reinterpret_cast<LSSetApplicationInformationItemType>(
-                CFBundleGetFunctionPointerForName(
-                    launch_services_bundle,
-                    CFSTR("_LSSetApplicationInformationItem")));
-
-        key_pointer = reinterpret_cast<CFStringRef*>(
-                    CFBundleGetDataPointerForName(launch_services_bundle,
-                                                  CFSTR("_kLSDisplayNameKey")));
-
-        ls_display_name_key = key_pointer ? *key_pointer : NULL;
-        GetCurrentProcess(&psn);
-    }
-
-    if (!ls_get_current_application_asn_func
-            || !ls_set_application_information_item_func
-            || !ls_display_name_key)
-    {
-        CFRelease(process_name);
-        return;
-    }
-
-    PrivateLSASN asn = ls_get_current_application_asn_func();
-    const int magic_session_constant = -2;
-    ls_set_application_information_item_func(magic_session_constant, asn,
-                                             ls_display_name_key, process_name, NULL /* optional out param */);
-    CFRelease(process_name);
 }
 
-char *runWithRootPrivileges(char *command)
+void closeFileSelectionPanels(QWidget* parent)
 {
-    if (!command)
+    if(panel)
     {
-        return NULL;
+        NSWindow* panelParentWindow(nullptr);
+        NSView* checkParentview = (__bridge NSView*)reinterpret_cast<void*>(parent->window()->winId());
+        NSWindow* checkParentWindow = [checkParentview window];
+        panelParentWindow = [panel sheetParent];
+        if(checkParentWindow == panelParentWindow)
+        {
+            [panelParentWindow endSheet: panel];
+        }
     }
-
-    OSStatus status;
-    AuthorizationRef authorizationRef;
-    NSString *appPath = [[NSBundle mainBundle] bundlePath];
-    if (appPath == nil)
-    {
-        return NULL;
-    }
-
-    NSString *pathToIcon = [appPath stringByAppendingString:@"/Contents/Resources/appicon32.tiff"];
-    const char *icon = [pathToIcon fileSystemRepresentation];
-    if (!icon)
-    {
-        return NULL;
-    }
-
-    const char *prompt = "MEGAsync. ";
-    char *result = NULL;
-    FILE *pipe = NULL;
-    char* args[3];
-    args [0] = "-e";
-    args [1] = command;
-    args [2] = NULL;
-
-    AuthorizationItem kAuthEnv[] = {
-            { kAuthorizationEnvironmentIcon, strlen(icon), (void*)icon, 0 },
-            { kAuthorizationEnvironmentPrompt, strlen(prompt), (char *)prompt, 0}};
-    AuthorizationEnvironment myAuthorizationEnvironment = { 2, kAuthEnv };
-    AuthorizationItem right = {kAuthorizationRightExecute, 0, NULL, 0};
-    AuthorizationRights rights = {1, &right};
-    AuthorizationFlags flags = kAuthorizationFlagDefaults | kAuthorizationFlagInteractionAllowed
-            | kAuthorizationFlagPreAuthorize | kAuthorizationFlagExtendRights;
-
-    status = AuthorizationCreate(NULL, kAuthorizationEmptyEnvironment,
-                                     kAuthorizationFlagDefaults, &authorizationRef);
-    if (status != errAuthorizationSuccess)
-    {
-        return NULL;
-    }
-
-    // Call AuthorizationCopyRights to determine rights.
-    status = AuthorizationCopyRights(authorizationRef, &rights, &myAuthorizationEnvironment, flags, NULL);
-    if (status != errAuthorizationSuccess)
-    {
-        AuthorizationFree(authorizationRef, kAuthorizationFlagDestroyRights);
-        return NULL;
-    }
-
-    status = AuthorizationExecuteWithPrivileges(authorizationRef, "/usr/bin/osascript",
-                                                kAuthorizationFlagDefaults, args, &pipe);
-    AuthorizationFree(authorizationRef, kAuthorizationFlagDestroyRights);
-    if (status == errAuthorizationSuccess)
-    {
-        result = new char[1025];
-        memset(result, 0, 1025);
-        fread(result, 1024, 1, pipe);
-        fclose(pipe);
-    }
-
-    return result;
 }
 
 bool startAtLogin(bool opt)
 {
-    NSString *appPath = [[NSBundle mainBundle] bundlePath];
-    if (appPath == nil)
+    if (opt)
     {
-        return false;
-    }
-
-    CFURLRef url = (CFURLRef)[NSURL fileURLWithPath:appPath];
-    if (url == nil)
-    {
-        return false;
-    }
-
-    LSSharedFileListRef loginItems = LSSharedFileListCreate(NULL, kLSSharedFileListSessionLoginItems, NULL);
-    if (loginItems == nil)
-    {
-        return false;
-    }
-
-    // Remove duplicates
-    UInt32 seed = 0U;
-    NSArray *items = (NSArray *)LSSharedFileListCopySnapshot(loginItems, &seed);
-    if (items)
-    {
-        for (id item in items)
+        //Enable start at login
+        if (!isStartAtLoginActive())
         {
-            LSSharedFileListItemRef itemRef = (LSSharedFileListItemRef)item;
-            if (itemRef)
-            {
-                CFURLRef itemURL = NULL;
-                if (LSSharedFileListItemResolve(itemRef, 0, (CFURLRef*) &itemURL, NULL) == noErr && itemURL
-                        && CFEqual(url, itemURL))
-                {
-                    // Remove duplicates with the same target URL
-                    LSSharedFileListItemRemove(loginItems, itemRef);
-                }
-                else
-                {
-                    CFStringRef itemName = LSSharedFileListItemCopyDisplayName(itemRef);
-                    if (itemName)
-                    {
-                        // Remove duplicates called "MEGAsync"
-                        if ([(NSString *)itemName isEqualToString:@"MEGAsync"])
-                        {
-                            LSSharedFileListItemRemove(loginItems, itemRef);
-                        }
-                        CFRelease(itemName);
-                    }
-                }
-
-                if (itemURL)
-                {
-                    CFRelease(itemURL);
-                }
-            }
+            addLoginItem();
         }
-        CFRelease(items);
-    }
-
-    bool result = false;
-    if (!opt)
-    {
-        //Disable start at login
-        result = true;
     }
     else
     {
-        //Enable start at login
-        //Insert an item to the login list.
-        LSSharedFileListItemRef item = LSSharedFileListInsertItemURL(loginItems, kLSSharedFileListItemLast,
-                                                                     NULL, NULL, url, NULL, NULL);
-        if (item)
-        {
-            CFRelease(item);
-            result = true;
-        }
-    }
-    CFRelease(loginItems);
-    return result;
-}
-
-bool isStartAtLoginActive()
-{
-    NSString *appPath = [[NSBundle mainBundle] bundlePath];
-    if (appPath == nil)
-    {
-        return false;
+        removeLoginItem();
     }
 
-    // This will get the path for the application
-    NSURL *url = [NSURL fileURLWithPath:appPath];
-    if (url == nil)
-    {
-        return false;
-    }
-
-    LSSharedFileListRef loginItems = LSSharedFileListCreate(NULL, kLSSharedFileListSessionLoginItems, NULL);
-    if (loginItems == nil)
-    {
-        return false;
-    }
-
-    UInt32 seed = 0U;
-    Boolean foundIt = false;
-    UInt32 resolutionFlags = kLSSharedFileListNoUserInteraction | kLSSharedFileListDoNotMountVolumes;
-    NSArray *currentLoginItems = (NSArray *)LSSharedFileListCopySnapshot(loginItems, &seed);
-    if (currentLoginItems)
-    {
-        for (id itemObject in currentLoginItems)
-        {
-            LSSharedFileListItemRef item = (LSSharedFileListItemRef)itemObject;
-            if (item)
-            {
-                CFURLRef itemURL = NULL;
-                if (LSSharedFileListItemResolve(item, resolutionFlags, &itemURL, NULL) == noErr && itemURL)
-                {
-                    foundIt = CFEqual(itemURL, url);
-                    CFRelease(itemURL);
-                    if (foundIt)
-                    {
-                        break;
-                    }
-                }
-            }
-        }
-        CFRelease(currentLoginItems);
-    }
-
-    CFRelease(loginItems);
-    return (BOOL)foundIt;
+    return true;
 }
 
 void addPathToPlaces(QString path, QString pathName)
@@ -534,7 +332,12 @@ void setFolderIcon(QString path)
     }
 
     NSImage* iconImage = NULL;
-    if (floor(kCFCoreFoundationVersionNumber) > kCFCoreFoundationVersionNumber10_9)
+    auto osVersion = QOperatingSystemVersion::current();
+    if (osVersion >= QOperatingSystemVersion::MacOSBigSur)
+    {
+        iconImage = [[NSImage alloc] initWithContentsOfFile:[appPath stringByAppendingString:@"/Contents/Resources/folder_bigsur.icns"]];
+    }
+    else if (osVersion >= QOperatingSystemVersion::OSXYosemite)
     {
         iconImage = [[NSImage alloc] initWithContentsOfFile:[appPath stringByAppendingString:@"/Contents/Resources/folder_yosemite.icns"]];
     }
@@ -673,7 +476,7 @@ bool registerUpdateDaemon()
         return false;
     }
 
-    return p.exitCode();
+    return p.exitCode() ? false : true;
 }
 
 // Check if it's needed to start the local HTTP server
@@ -727,57 +530,6 @@ bool runHttpServer()
     return false;
 }
 
-// Check if it's needed to start the local HTTPS server
-// for communications with the webclient
-bool runHttpsServer()
-{
-    int nProcesses = proc_listpids(PROC_ALL_PIDS, 0, NULL, 0);
-    int pidBufSize = nProcesses * sizeof(pid_t);
-    pid_t *pids = new pid_t[nProcesses];
-    memset(pids, 0, pidBufSize);
-    proc_listpids(PROC_ALL_PIDS, 0, pids, pidBufSize);
-
-    for (int i = 0; i < nProcesses; ++i)
-    {
-        if (pids[i] == 0)
-        {
-            continue;
-        }
-
-        char processPath[PROC_PIDPATHINFO_MAXSIZE];
-        memset(processPath, 0, PROC_PIDPATHINFO_MAXSIZE);
-        if (proc_pidpath(pids[i], processPath, PROC_PIDPATHINFO_MAXSIZE) <= 0)
-        {
-            continue;
-        }
-
-        int position = strlen(processPath);
-        if (position > 0)
-        {
-            while (position >= 0 && processPath[position] != '/')
-            {
-                position--;
-            }
-
-            // The MEGA webclient sends request to MEGAsync to improve the
-            // user experience. We check if web browsers are running because
-            // otherwise it isn't needed to run the local web server for this purpose.
-            // Here is the list or web browsers that don't allow HTTP communications
-            // with 127.0.0.1 inside HTTPS webs and therefore require a HTTPS server.
-            QString processName = QString::fromUtf8(processPath + position + 1);
-            if (!processName.compare(QString::fromUtf8("Safari"), Qt::CaseInsensitive)
-                || !processName.compare(QString::fromUtf8("Opera"), Qt::CaseInsensitive))
-            {
-                delete [] pids;
-                return true;
-            }
-        }
-    }
-
-    delete [] pids;
-    return false;
-}
-
 bool userActive()
 {
     CFTimeInterval secondsSinceLastEvent = CGEventSourceSecondsSinceLastEventType(kCGEventSourceStateHIDSystemState, kCGAnyInputEventType);
@@ -803,38 +555,103 @@ double uptime()
     return difftime(csec, bsec);
 }
 
-id allocatePopOverWithView(id view, QSize size)
+QString appBundlePath()
 {
-    //Check we have received a valid NSView
-    if ([view isKindOfClass:[NSView class]])
+    NSString *appPath = [[NSBundle mainBundle] bundlePath];
+    if (appPath == nil)
     {
-        NSPopover *m_popover = [[NSPopover alloc] init];
-        [m_popover setBackgroundColor:[NSColor whiteColor]];
-        [m_popover setContentSize:NSMakeSize((CGFloat)size.width() + 2, (CGFloat)size.height() + 2)];
-        [m_popover setBehavior:NSPopoverBehaviorTransient];
-        [m_popover setAnimates:YES];
-        [m_popover setContentViewController:[[ProgramaticViewController alloc] initWithView:(NSView*)view]];
-
-        return m_popover;
+        return QString();
     }
 
-    return nil;
+    return fromNSString(appPath);
 }
 
-void showPopOverRelativeToRect(WId view, id popOver, QPointF rect)
-{
-    NSView *thisView = (__bridge NSView *)reinterpret_cast<void *>(view);
 
-    //Check we have received a valid NSView
-    if (thisView &&
-         [popOver isKindOfClass:[NSPopover class]])
+bool isStartAtLoginActive()
+{
+    NSString *appPath = [[NSBundle mainBundle] bundlePath];
+    CFURLRef url = (__bridge CFURLRef)[NSURL fileURLWithPath:appPath];
+
+    LSSharedFileListRef loginItems = LSSharedFileListCreate(NULL, kLSSharedFileListSessionLoginItems, NULL);
+    if (loginItems)
     {
-        NSRect position = CGRectMake(rect.x(), rect.y(), 1, 1);
-        [popOver showRelativeToRect:position ofView:thisView preferredEdge:NSMinYEdge];
+        // Look for app login item
+        UInt32 seed = 0U;
+        NSArray *items = (NSArray *)CFBridgingRelease(LSSharedFileListCopySnapshot(loginItems, &seed));
+        if (items)
+        {
+            for (id item in items)
+            {
+                LSSharedFileListItemRef itemRef = (__bridge LSSharedFileListItemRef)item;
+                if (itemRef)
+                {
+                    // Resolve the item with URL
+                    if (LSSharedFileListItemResolve(itemRef, 0, (CFURLRef *)&url, NULL) == noErr)
+                    {
+                        NSString *urlPath = [(__bridge NSURL *)url path];
+                        if ([urlPath compare:appPath] == NSOrderedSame)
+                        {
+                            return true;
+                        }
+                    }
+                }
+            }
+        }
+    }
+
+    return false;
+}
+
+void addLoginItem()
+{
+    NSString *appPath = [[NSBundle mainBundle] bundlePath];
+
+    // This will get the path for the application
+    // For example, /Applications/MEGAsync.app
+    CFURLRef url = (__bridge CFURLRef)[NSURL fileURLWithPath:appPath];
+
+    // Create a reference to the shared file list.
+    // Adding it to the current user only (kLSSharedFileListSessionLoginItems)
+    LSSharedFileListRef loginItems = LSSharedFileListCreate(NULL, kLSSharedFileListSessionLoginItems, NULL);
+    if (loginItems)
+    {
+        // Insert an item to the login item list.
+        LSSharedFileListItemRef item = LSSharedFileListInsertItemURL(loginItems, kLSSharedFileListItemLast, NULL, NULL, url, NULL, NULL);
+        if (item)
+        {
+            CFRelease(item);
+        }
+
+        CFRelease(loginItems);
+    }    
+}
+
+void removeLoginItem()
+{
+    NSString *appPath = [[NSBundle mainBundle] bundlePath];
+    CFURLRef url = (__bridge CFURLRef)[NSURL fileURLWithPath:appPath];
+
+    // Create a reference to the shared file list.
+    LSSharedFileListRef loginItems = LSSharedFileListCreate(NULL, kLSSharedFileListSessionLoginItems, NULL);
+    if (loginItems)
+    {
+        UInt32 seedValue = 0U;
+        NSArray  *items = (NSArray *)CFBridgingRelease(LSSharedFileListCopySnapshot(loginItems, &seedValue));
+        for (id item in items)
+        {
+            LSSharedFileListItemRef itemRef = (__bridge LSSharedFileListItemRef)item;
+            if (itemRef)
+            {
+                if (LSSharedFileListItemResolve(itemRef, 0, (CFURLRef *)&url, NULL) == noErr)
+                {
+                    NSString *urlPath = [(__bridge NSURL *)url path];
+                    if ([urlPath compare:appPath] == NSOrderedSame)
+                    {
+                        // Remove an item to the login item list.
+                        LSSharedFileListItemRemove(loginItems, itemRef);
+                    }
+                }
+            }
+        }
     }
 }
-
-void releaseIdObject(id obj)
-{
-    [obj release];
-}
