@@ -1,6 +1,8 @@
 #ifndef MACXLOCALSOCKETPRIVATE_H
 #define MACXLOCALSOCKETPRIVATE_H
 
+#include <QMutex>
+
 #include "Protocol.h"
 #include "MacXLocalSocket.h"
 
@@ -10,10 +12,20 @@ public:
     MacXLocalSocket *socket;
     NSDistantObject<CommunicationProtocol> *extClient;
     id client;
-    QByteArray buf;
 
     MacXLocalSocketPrivate(NSDistantObject<CommunicationProtocol> *extClient);
     ~MacXLocalSocketPrivate();
+
+    void appendToBuffer(QByteArray info);
+    void clearBuffer();
+    void removeFromBuffer(int pos, int size);
+    QByteArray midFromBuffer(int pos, int size);
+    int bufferSize();
+    QByteArray getBuffer();
+
+private:
+    QByteArray buf;
+    QMutex mBufferMutex;
 };
 
 #endif // MACXLOCALSOCKETPRIVATE_H
