@@ -356,7 +356,7 @@ VOID WinShellDispatcherTask::GetAnswerToRequest(LPPIPEINST pipe)
             }
 
             bool ok;
-            QStringList parameters = QString::fromWCharArray(content).split(QChar::fromAscii(':'));
+            QStringList parameters = QString::fromWCharArray(content).split(QChar::fromLatin1(':'));
             if (parameters.size() < 1)
             {
                 break;
@@ -375,8 +375,16 @@ VOID WinShellDispatcherTask::GetAnswerToRequest(LPPIPEINST pipe)
                     actionString = QCoreApplication::translate("ShellExtension", "Upload to MEGA");
                     break;
                 case STRING_GETLINK:
-                    actionString = QCoreApplication::translate("ShellExtension", "Get MEGA link");
+                {
+                    //Only for non incoming share syncs
+                    string tmpPath((const char*)lastPath.utf16(), lastPath.size()*sizeof(wchar_t));
+                    std::unique_ptr<MegaNode> node(MegaSyncApp->getMegaApi()->getSyncedNode(&tmpPath));
+                    if(!Utilities::isIncommingShare(node.get()))
+                    {
+                        actionString = QCoreApplication::translate("ShellExtension", "Get MEGA link");
+                    }
                     break;
+                }
                 case STRING_SHARE:
                     actionString = QCoreApplication::translate("ShellExtension", "Share with a MEGA user");
                     break;
@@ -394,7 +402,11 @@ VOID WinShellDispatcherTask::GetAnswerToRequest(LPPIPEINST pipe)
                     break;
             }
 
-            wcscpy_s( pipe->chReply, BUFSIZE, (const wchar_t *)actionString.utf16());
+            if(!actionString.isEmpty())
+            {
+                wcscpy_s(pipe->chReply, BUFSIZE, (const wchar_t *)actionString.utf16());
+            }
+
             break;
         }
         case L'F':
@@ -404,7 +416,7 @@ VOID WinShellDispatcherTask::GetAnswerToRequest(LPPIPEINST pipe)
                 break;
             }
             QString filePath = QString::fromWCharArray(content);
-            if (filePath.startsWith(QString::fromAscii("\\\\?\\")))
+            if (filePath.startsWith(QString::fromLatin1("\\\\?\\")))
             {
                 filePath = filePath.mid(4);
             }
@@ -425,7 +437,7 @@ VOID WinShellDispatcherTask::GetAnswerToRequest(LPPIPEINST pipe)
             }
 
             QString filePath = QString::fromWCharArray(content);
-            if (filePath.startsWith(QString::fromAscii("\\\\?\\")))
+            if (filePath.startsWith(QString::fromLatin1("\\\\?\\")))
             {
                 filePath = filePath.mid(4);
             }
@@ -447,7 +459,7 @@ VOID WinShellDispatcherTask::GetAnswerToRequest(LPPIPEINST pipe)
             }
 
             bool overlayIcons = true;
-            QStringList parameters = QString::fromWCharArray(content).split(QChar::fromAscii('|'));
+            QStringList parameters = QString::fromWCharArray(content).split(QChar::fromLatin1('|'));
             if (parameters.size() > 1)
             {
                 bool ok;
@@ -465,7 +477,7 @@ VOID WinShellDispatcherTask::GetAnswerToRequest(LPPIPEINST pipe)
 
             int state;
             QString temp = parameters[0];
-            if (temp.startsWith(QString::fromAscii("\\\\?\\")))
+            if (temp.startsWith(QString::fromLatin1("\\\\?\\")))
             {
                 temp = temp.mid(4);
             }
@@ -489,18 +501,18 @@ VOID WinShellDispatcherTask::GetAnswerToRequest(LPPIPEINST pipe)
             switch(state)
             {
                 case MegaApi::STATE_SYNCED:
-                    wcscpy_s( pipe->chReply, BUFSIZE, RESPONSE_SYNCED );
+                    wcscpy_s( pipe->chReply, BUFSIZE, RESPONSE_SYNCED);
                     break;
                 case MegaApi::STATE_SYNCING:
-                     wcscpy_s( pipe->chReply, BUFSIZE, RESPONSE_SYNCING );
-                     break;
+                    wcscpy_s( pipe->chReply, BUFSIZE, RESPONSE_SYNCING );
+                    break;
                 case MegaApi::STATE_PENDING:
-                     wcscpy_s( pipe->chReply, BUFSIZE, RESPONSE_PENDING );
-                     break;
+                    wcscpy_s( pipe->chReply, BUFSIZE, RESPONSE_PENDING );
+                    break;
                 case MegaApi::STATE_NONE:
                 case MegaApi::STATE_IGNORED:
                 default:
-                     wcscpy_s( pipe->chReply, BUFSIZE, RESPONSE_DEFAULT );
+                    wcscpy_s( pipe->chReply, BUFSIZE, RESPONSE_DEFAULT );
             }
             break;
         }
