@@ -6,7 +6,7 @@
 
 #include "MegaApplication.h"
 #include "megaapi.h"
-#include "control/Preferences.h"
+#include "control/Preferences/Preferences.h"
 
 #include <windows.h>
 #include <winbase.h>
